Class ActionServiceUpdateTargetRequest

java.lang.Object
com.zitadel.model.ActionServiceUpdateTargetRequest

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class ActionServiceUpdateTargetRequest extends Object
ActionServiceUpdateTargetRequest
  • Field Details

  • Constructor Details

    • ActionServiceUpdateTargetRequest

      public ActionServiceUpdateTargetRequest()
  • Method Details

    • id

    • getId

      @Nullable public String getId()
      The unique identifier of the target to update.
      Returns:
      id
    • setId

      public void setId(@Nullable String id)
    • name

    • getName

      @Nullable public String getName()
      Optionally, update the name of the target. If not set, the name will not be changed.
      Returns:
      name
    • getName_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getName_JsonNullable()
    • setName_JsonNullable

      public void setName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> name)
    • setName

      public void setName(@Nullable String name)
    • timeout

    • getTimeout

      @Nullable public String getTimeout()
      A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like \"day\" or \"month\". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +-10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = ...; Timestamp end = ...; Duration duration = ...; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds += 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos += 1000000000; } Example 2: Compute Timestamp from Timestamp + Duration in pseudo code. Timestamp start = ...; Duration duration = ...; Timestamp end = ...; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos += 1000000000; } else if (end.nanos >= 1000000000) { end.seconds += 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix \"s\" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as \"3s\", while 3 seconds and 1 nanosecond should be expressed in JSON format as \"3.000000001s\", and 3 seconds and 1 microsecond should be expressed in JSON format as \"3.000001s\".
      Returns:
      timeout
    • setTimeout

      public void setTimeout(@Nullable String timeout)
    • endpoint

    • getEndpoint

      @Nullable public String getEndpoint()
      The new URL of the endpoint to call. If not set, the endpoint will not be changed.
      Returns:
      endpoint
    • getEndpoint_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getEndpoint_JsonNullable()
    • setEndpoint_JsonNullable

      public void setEndpoint_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> endpoint)
    • setEndpoint

      public void setEndpoint(@Nullable String endpoint)
    • expirationSigningKey

      public ActionServiceUpdateTargetRequest expirationSigningKey(@Nullable String expirationSigningKey)
    • getExpirationSigningKey

      @Nullable public String getExpirationSigningKey()
      A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like \"day\" or \"month\". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +-10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = ...; Timestamp end = ...; Duration duration = ...; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds += 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos += 1000000000; } Example 2: Compute Timestamp from Timestamp + Duration in pseudo code. Timestamp start = ...; Duration duration = ...; Timestamp end = ...; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos += 1000000000; } else if (end.nanos >= 1000000000) { end.seconds += 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix \"s\" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as \"3s\", while 3 seconds and 1 nanosecond should be expressed in JSON format as \"3.000000001s\", and 3 seconds and 1 microsecond should be expressed in JSON format as \"3.000001s\".
      Returns:
      expirationSigningKey
    • setExpirationSigningKey

      public void setExpirationSigningKey(@Nullable String expirationSigningKey)
    • payloadType

    • getPayloadType

      @Nullable public ActionServicePayloadType getPayloadType()
      Get payloadType
      Returns:
      payloadType
    • setPayloadType

      public void setPayloadType(@Nullable ActionServicePayloadType payloadType)
    • restAsync

      public ActionServiceUpdateTargetRequest restAsync(@Nullable Object restAsync)
    • getRestAsync

      @Nullable public Object getRestAsync()
      Get restAsync
      Returns:
      restAsync
    • setRestAsync

      public void setRestAsync(@Nullable Object restAsync)
    • restCall

    • getRestCall

      @Nullable public ActionServiceRESTCall getRestCall()
      Get restCall
      Returns:
      restCall
    • setRestCall

      public void setRestCall(@Nullable ActionServiceRESTCall restCall)
    • restWebhook

    • getRestWebhook

      @Nullable public ActionServiceRESTWebhook getRestWebhook()
      Get restWebhook
      Returns:
      restWebhook
    • setRestWebhook

      public void setRestWebhook(@Nullable ActionServiceRESTWebhook restWebhook)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string