Package com.zitadel.model
Class ApplicationServiceUpdateApplicationRequest
java.lang.Object
com.zitadel.model.ApplicationServiceUpdateApplicationRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ApplicationServiceUpdateApplicationRequest
extends Object
ApplicationServiceUpdateApplicationRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionapiConfiguration(ApplicationServiceUpdateAPIApplicationConfigurationRequest apiConfiguration) applicationId(String applicationId) booleanGet apiConfigurationThe unique ID of the application to be updated.getName()Publicly visible name of the application.Get oidcConfigurationThe ID of the project the application belongs to.Get samlConfigurationinthashCode()oidcConfiguration(ApplicationServiceUpdateOIDCApplicationConfigurationRequest oidcConfiguration) samlConfiguration(ApplicationServiceUpdateSAMLApplicationConfigurationRequest samlConfiguration) voidvoidsetApplicationId(String applicationId) voidvoidsetOidcConfiguration(ApplicationServiceUpdateOIDCApplicationConfigurationRequest oidcConfiguration) voidsetProjectId(String projectId) voidsetSamlConfiguration(ApplicationServiceUpdateSAMLApplicationConfigurationRequest samlConfiguration) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_APPLICATION_ID
- See Also:
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
JSON_PROPERTY_NAME
- See Also:
-
JSON_PROPERTY_API_CONFIGURATION
- See Also:
-
JSON_PROPERTY_OIDC_CONFIGURATION
- See Also:
-
JSON_PROPERTY_SAML_CONFIGURATION
- See Also:
-
-
Constructor Details
-
ApplicationServiceUpdateApplicationRequest
public ApplicationServiceUpdateApplicationRequest()
-
-
Method Details
-
applicationId
-
getApplicationId
The unique ID of the application to be updated.- Returns:
- applicationId
-
setApplicationId
-
projectId
-
getProjectId
The ID of the project the application belongs to.- Returns:
- projectId
-
setProjectId
-
name
-
getName
Publicly visible name of the application. This might be presented to users if they sign in. If not set, the name will not be changed.- Returns:
- name
-
setName
-
apiConfiguration
public ApplicationServiceUpdateApplicationRequest apiConfiguration(@Nullable ApplicationServiceUpdateAPIApplicationConfigurationRequest apiConfiguration) -
getApiConfiguration
Get apiConfiguration- Returns:
- apiConfiguration
-
setApiConfiguration
public void setApiConfiguration(@Nullable ApplicationServiceUpdateAPIApplicationConfigurationRequest apiConfiguration) -
oidcConfiguration
public ApplicationServiceUpdateApplicationRequest oidcConfiguration(@Nullable ApplicationServiceUpdateOIDCApplicationConfigurationRequest oidcConfiguration) -
getOidcConfiguration
Get oidcConfiguration- Returns:
- oidcConfiguration
-
setOidcConfiguration
public void setOidcConfiguration(@Nullable ApplicationServiceUpdateOIDCApplicationConfigurationRequest oidcConfiguration) -
samlConfiguration
public ApplicationServiceUpdateApplicationRequest samlConfiguration(@Nullable ApplicationServiceUpdateSAMLApplicationConfigurationRequest samlConfiguration) -
getSamlConfiguration
Get samlConfiguration- Returns:
- samlConfiguration
-
setSamlConfiguration
public void setSamlConfiguration(@Nullable ApplicationServiceUpdateSAMLApplicationConfigurationRequest samlConfiguration) -
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-