Class ApplicationServiceUpdateOIDCApplicationConfigurationRequest

java.lang.Object
com.zitadel.model.ApplicationServiceUpdateOIDCApplicationConfigurationRequest

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class ApplicationServiceUpdateOIDCApplicationConfigurationRequest extends Object
ApplicationServiceUpdateOIDCApplicationConfigurationRequest
  • Field Details

  • Constructor Details

    • ApplicationServiceUpdateOIDCApplicationConfigurationRequest

      public ApplicationServiceUpdateOIDCApplicationConfigurationRequest()
  • Method Details

    • redirectUris

    • addRedirectUrisItem

      public ApplicationServiceUpdateOIDCApplicationConfigurationRequest addRedirectUrisItem(String redirectUrisItem)
    • getRedirectUris

      @Nullable public List<String> getRedirectUris()
      RedirectURIs are the allowed callback URIs for the OAuth2 / OIDC flows, where the authorization code or tokens will be sent to. The redirect_uri parameter in the authorization request must exactly match one of these URIs. Any existing redirect URIs not included in this list will be removed. If not set, the redirect URIs will not be changed.
      Returns:
      redirectUris
    • setRedirectUris

      public void setRedirectUris(@Nullable List<String> redirectUris)
    • responseTypes

    • addResponseTypesItem

    • getResponseTypes

      ResponseTypes define whether a code, id_token token or just id_token will be returned. The response_type parameter in the authorization request must exactly match one of these values. Any existing response types not included in this list will be removed. If not set, the response types will not be changed.
      Returns:
      responseTypes
    • setResponseTypes

      public void setResponseTypes(@Nullable List<ApplicationServiceOIDCResponseType> responseTypes)
    • grantTypes

    • addGrantTypesItem

    • getGrantTypes

      GrantTypes define the flow type the application is allowed to use. The grant_type parameter in the token request must exactly match one of these values. Minimum one grant type must be provided, but multiple grant types can be provided to allow different flows, e.g. authorization code flow and refresh token flow. Any existing grant types not included in this list will be removed. If not set, the grant types will not be changed.
      Returns:
      grantTypes
    • setGrantTypes

      public void setGrantTypes(@Nullable List<ApplicationServiceOIDCGrantType> grantTypes)
    • applicationType

    • getApplicationType

      @Nullable public ApplicationServiceOIDCApplicationType getApplicationType()
      Get applicationType
      Returns:
      applicationType
    • setApplicationType

      public void setApplicationType(@Nullable ApplicationServiceOIDCApplicationType applicationType)
    • authMethodType

    • getAuthMethodType

      @Nullable public ApplicationServiceOIDCAuthMethodType getAuthMethodType()
      Get authMethodType
      Returns:
      authMethodType
    • setAuthMethodType

      public void setAuthMethodType(@Nullable ApplicationServiceOIDCAuthMethodType authMethodType)
    • postLogoutRedirectUris

      public ApplicationServiceUpdateOIDCApplicationConfigurationRequest postLogoutRedirectUris(@Nullable List<String> postLogoutRedirectUris)
    • addPostLogoutRedirectUrisItem

      public ApplicationServiceUpdateOIDCApplicationConfigurationRequest addPostLogoutRedirectUrisItem(String postLogoutRedirectUrisItem)
    • getPostLogoutRedirectUris

      @Nullable public List<String> getPostLogoutRedirectUris()
      PostLogoutRedirectURIs are the allowed URIs to redirect to after a logout. The post_logout_redirect_uri parameter in the logout request must exactly match one of these URIs. Any existing post logout redirect URIs not included in this list will be removed. If not set, the post logout redirect URIs will not be changed.
      Returns:
      postLogoutRedirectUris
    • setPostLogoutRedirectUris

      public void setPostLogoutRedirectUris(@Nullable List<String> postLogoutRedirectUris)
    • version

    • getVersion

      Get version
      Returns:
      version
    • setVersion

      public void setVersion(@Nullable ApplicationServiceOIDCVersion version)
    • developmentMode

    • getDevelopmentMode

      @Nullable public Boolean getDevelopmentMode()
      DevelopmentMode can be enabled for development purposes. This allows the use of OIDC non-compliant and potentially insecure settings, such as the use of HTTP redirect URIs or wildcard redirect URIs. If not set, the dev mode will not be changed.
      Returns:
      developmentMode
    • getDevelopmentMode_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<Boolean> getDevelopmentMode_JsonNullable()
    • setDevelopmentMode_JsonNullable

      public void setDevelopmentMode_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> developmentMode)
    • setDevelopmentMode

      public void setDevelopmentMode(@Nullable Boolean developmentMode)
    • accessTokenType

    • getAccessTokenType

      @Nullable public ApplicationServiceOIDCTokenType getAccessTokenType()
      Get accessTokenType
      Returns:
      accessTokenType
    • setAccessTokenType

      public void setAccessTokenType(@Nullable ApplicationServiceOIDCTokenType accessTokenType)
    • accessTokenRoleAssertion

      public ApplicationServiceUpdateOIDCApplicationConfigurationRequest accessTokenRoleAssertion(@Nullable Boolean accessTokenRoleAssertion)
    • getAccessTokenRoleAssertion

      @Nullable public Boolean getAccessTokenRoleAssertion()
      If AccessTokenRoleAssertion is enabled, the roles of the user are added to the access token. Ensure that the access token is a JWT token and not a bearer token. And either request the roles by scope or enable the user role assertion on the project. If not set, the access token role assertion will not be changed.
      Returns:
      accessTokenRoleAssertion
    • getAccessTokenRoleAssertion_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<Boolean> getAccessTokenRoleAssertion_JsonNullable()
    • setAccessTokenRoleAssertion_JsonNullable

      public void setAccessTokenRoleAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> accessTokenRoleAssertion)
    • setAccessTokenRoleAssertion

      public void setAccessTokenRoleAssertion(@Nullable Boolean accessTokenRoleAssertion)
    • idTokenRoleAssertion

      public ApplicationServiceUpdateOIDCApplicationConfigurationRequest idTokenRoleAssertion(@Nullable Boolean idTokenRoleAssertion)
    • getIdTokenRoleAssertion

      @Nullable public Boolean getIdTokenRoleAssertion()
      If IDTokenRoleAssertion is enabled, the roles of the user are added to the id token. Ensure that either the roles are requested by scope or enable the user role assertion on the project. If not set, the id token role assertion will not be changed.
      Returns:
      idTokenRoleAssertion
    • getIdTokenRoleAssertion_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<Boolean> getIdTokenRoleAssertion_JsonNullable()
    • setIdTokenRoleAssertion_JsonNullable

      public void setIdTokenRoleAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> idTokenRoleAssertion)
    • setIdTokenRoleAssertion

      public void setIdTokenRoleAssertion(@Nullable Boolean idTokenRoleAssertion)
    • idTokenUserinfoAssertion

      public ApplicationServiceUpdateOIDCApplicationConfigurationRequest idTokenUserinfoAssertion(@Nullable Boolean idTokenUserinfoAssertion)
    • getIdTokenUserinfoAssertion

      @Nullable public Boolean getIdTokenUserinfoAssertion()
      If IDTokenUserinfoAssertion is enabled, the claims of profile, email, address and phone scopes are added to the id token even if an access token is issued. This can be required by some applications that do not call the userinfo endpoint after authentication or directly use the id_token for retrieving user information. Attention: this violates the OIDC specification, which states that these claims must only be requested from the userinfo endpoint if an access token is issued. This is to prevent leaking of personal information in the id token, which is often stored in the browser and therefore more vulnerable. If not set, the id token userinfo assertion will not be changed.
      Returns:
      idTokenUserinfoAssertion
    • getIdTokenUserinfoAssertion_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<Boolean> getIdTokenUserinfoAssertion_JsonNullable()
    • setIdTokenUserinfoAssertion_JsonNullable

      public void setIdTokenUserinfoAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> idTokenUserinfoAssertion)
    • setIdTokenUserinfoAssertion

      public void setIdTokenUserinfoAssertion(@Nullable Boolean idTokenUserinfoAssertion)
    • clockSkew

    • getClockSkew

      @Nullable public String getClockSkew()
      A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like \"day\" or \"month\". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +-10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = ...; Timestamp end = ...; Duration duration = ...; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds += 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos += 1000000000; } Example 2: Compute Timestamp from Timestamp + Duration in pseudo code. Timestamp start = ...; Duration duration = ...; Timestamp end = ...; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos += 1000000000; } else if (end.nanos >= 1000000000) { end.seconds += 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix \"s\" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as \"3s\", while 3 seconds and 1 nanosecond should be expressed in JSON format as \"3.000000001s\", and 3 seconds and 1 microsecond should be expressed in JSON format as \"3.000001s\".
      Returns:
      clockSkew
    • setClockSkew

      public void setClockSkew(@Nullable String clockSkew)
    • additionalOrigins

    • addAdditionalOriginsItem

      public ApplicationServiceUpdateOIDCApplicationConfigurationRequest addAdditionalOriginsItem(String additionalOriginsItem)
    • getAdditionalOrigins

      @Nullable public List<String> getAdditionalOrigins()
      AdditionalOrigins are HTTP origins (scheme + host + port) from where the API can be used additional to the redirect_uris. This is useful if the application is used from an origin different to the redirect_uris, e.g. if the application is a SPA served in a native app, where the redirect_uri is a custom scheme, but the application is served from a https origin. Any existing additional origins not included in this list will be removed. If not set, the additional origins will not be changed.
      Returns:
      additionalOrigins
    • setAdditionalOrigins

      public void setAdditionalOrigins(@Nullable List<String> additionalOrigins)
    • skipNativeAppSuccessPage

      public ApplicationServiceUpdateOIDCApplicationConfigurationRequest skipNativeAppSuccessPage(@Nullable Boolean skipNativeAppSuccessPage)
    • getSkipNativeAppSuccessPage

      @Nullable public Boolean getSkipNativeAppSuccessPage()
      For native apps a successful login usually shows a success page with a link to open the application again. SkipNativeAppSuccessPage can be used to skip this page and open the application directly. If not set, the skip native app success page will not be changed.
      Returns:
      skipNativeAppSuccessPage
    • getSkipNativeAppSuccessPage_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<Boolean> getSkipNativeAppSuccessPage_JsonNullable()
    • setSkipNativeAppSuccessPage_JsonNullable

      public void setSkipNativeAppSuccessPage_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> skipNativeAppSuccessPage)
    • setSkipNativeAppSuccessPage

      public void setSkipNativeAppSuccessPage(@Nullable Boolean skipNativeAppSuccessPage)
    • backChannelLogoutUri

      public ApplicationServiceUpdateOIDCApplicationConfigurationRequest backChannelLogoutUri(@Nullable String backChannelLogoutUri)
    • getBackChannelLogoutUri

      @Nullable public String getBackChannelLogoutUri()
      BackChannelLogoutURI is used to notify the application about terminated sessions according to the OIDC Back-Channel Logout (https://openid.net/specs/openid-connect-backchannel-1_0.html). If not set, the back channel logout URI will not be changed.
      Returns:
      backChannelLogoutUri
    • getBackChannelLogoutUri_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getBackChannelLogoutUri_JsonNullable()
    • setBackChannelLogoutUri_JsonNullable

      public void setBackChannelLogoutUri_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> backChannelLogoutUri)
    • setBackChannelLogoutUri

      public void setBackChannelLogoutUri(@Nullable String backChannelLogoutUri)
    • loginVersion

    • getLoginVersion

      @Nullable public ApplicationServiceLoginVersion getLoginVersion()
      Get loginVersion
      Returns:
      loginVersion
    • setLoginVersion

      public void setLoginVersion(@Nullable ApplicationServiceLoginVersion loginVersion)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string