Package com.zitadel.model
Class AuthorizationServiceProjectNameQuery
java.lang.Object
com.zitadel.model.AuthorizationServiceProjectNameQuery
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class AuthorizationServiceProjectNameQuery
extends Object
AuthorizationServiceProjectNameQuery
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanGet methodgetName()Specify the name of the project the user was granted the authorization for to search for.inthashCode()voidvoidtoString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_NAME
- See Also:
-
JSON_PROPERTY_METHOD
- See Also:
-
-
Constructor Details
-
AuthorizationServiceProjectNameQuery
public AuthorizationServiceProjectNameQuery()
-
-
Method Details
-
name
-
getName
Specify the name of the project the user was granted the authorization for to search for. Note that this will also include authorizations granted for project grants of the same project.- Returns:
- name
-
setName
-
method
public AuthorizationServiceProjectNameQuery method(@Nullable AuthorizationServiceTextFilterMethod method) -
getMethod
Get method- Returns:
- method
-
setMethod
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-