Package com.zitadel.model
Class AuthorizationServiceRoleKeyQuery
java.lang.Object
com.zitadel.model.AuthorizationServiceRoleKeyQuery
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class AuthorizationServiceRoleKeyQuery
extends Object
AuthorizationServiceRoleKeyQuery
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleangetKey()Specify the key of the role the user was granted to search for.Get methodinthashCode()voidvoidtoString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_KEY
- See Also:
-
JSON_PROPERTY_METHOD
- See Also:
-
-
Constructor Details
-
AuthorizationServiceRoleKeyQuery
public AuthorizationServiceRoleKeyQuery()
-
-
Method Details
-
key
-
getKey
Specify the key of the role the user was granted to search for.- Returns:
- key
-
setKey
-
method
public AuthorizationServiceRoleKeyQuery method(@Nullable AuthorizationServiceTextFilterMethod method) -
getMethod
Get method- Returns:
- method
-
setMethod
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-