Package com.zitadel.model
Class BetaProjectServiceCreateProjectGrantRequest
java.lang.Object
com.zitadel.model.BetaProjectServiceCreateProjectGrantRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class BetaProjectServiceCreateProjectGrantRequest
extends Object
BetaProjectServiceCreateProjectGrantRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddRoleKeysItem(String roleKeysItem) booleanOrganization the project is granted to.ID of the project.Keys of the role available for the project grant.grantedOrganizationId(String grantedOrganizationId) inthashCode()voidsetGrantedOrganizationId(String grantedOrganizationId) voidsetProjectId(String projectId) voidsetRoleKeys(List<String> roleKeys) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
JSON_PROPERTY_GRANTED_ORGANIZATION_ID
- See Also:
-
JSON_PROPERTY_ROLE_KEYS
- See Also:
-
-
Constructor Details
-
BetaProjectServiceCreateProjectGrantRequest
public BetaProjectServiceCreateProjectGrantRequest()
-
-
Method Details
-
projectId
-
getProjectId
ID of the project.- Returns:
- projectId
-
setProjectId
-
grantedOrganizationId
public BetaProjectServiceCreateProjectGrantRequest grantedOrganizationId(@Nullable String grantedOrganizationId) -
getGrantedOrganizationId
Organization the project is granted to.- Returns:
- grantedOrganizationId
-
setGrantedOrganizationId
-
roleKeys
-
addRoleKeysItem
-
getRoleKeys
Keys of the role available for the project grant.- Returns:
- roleKeys
-
setRoleKeys
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-