Package com.zitadel.model
Class BetaProjectServiceCreateProjectRequest
java.lang.Object
com.zitadel.model.BetaProjectServiceCreateProjectRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class BetaProjectServiceCreateProjectRequest
extends Object
BetaProjectServiceCreateProjectRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddAdminsItem(BetaProjectServiceAdmin adminsItem) admins(List<BetaProjectServiceAdmin> admins) authorizationRequired(Boolean authorizationRequired) booleanList of users and Project Member roles (PROJECT_OWNER, by default) to be assigned to those users.Deny authentication if the user has no authorization assigned to this project.getId()The unique identifier of the project.org.openapitools.jackson.nullable.JsonNullable<String>getName()Name of the project.The unique identifier of the organization the project belongs to.Get privateLabelingSettingBefore a user can be authenticated, it is verified that their affiliated organization has been granted access to this project.Enable this setting to provide role information to your application.inthashCode()organizationId(String organizationId) privateLabelingSetting(BetaProjectServicePrivateLabelingSetting privateLabelingSetting) projectAccessRequired(Boolean projectAccessRequired) projectRoleAssertion(Boolean projectRoleAssertion) voidsetAdmins(List<BetaProjectServiceAdmin> admins) voidsetAuthorizationRequired(Boolean authorizationRequired) voidvoidsetId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> id) voidvoidsetOrganizationId(String organizationId) voidsetPrivateLabelingSetting(BetaProjectServicePrivateLabelingSetting privateLabelingSetting) voidsetProjectAccessRequired(Boolean projectAccessRequired) voidsetProjectRoleAssertion(Boolean projectRoleAssertion) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_ORGANIZATION_ID
- See Also:
-
JSON_PROPERTY_ID
- See Also:
-
JSON_PROPERTY_NAME
- See Also:
-
JSON_PROPERTY_PROJECT_ROLE_ASSERTION
- See Also:
-
JSON_PROPERTY_AUTHORIZATION_REQUIRED
- See Also:
-
JSON_PROPERTY_PROJECT_ACCESS_REQUIRED
- See Also:
-
JSON_PROPERTY_PRIVATE_LABELING_SETTING
- See Also:
-
JSON_PROPERTY_ADMINS
- See Also:
-
-
Constructor Details
-
BetaProjectServiceCreateProjectRequest
public BetaProjectServiceCreateProjectRequest()
-
-
Method Details
-
organizationId
-
getOrganizationId
The unique identifier of the organization the project belongs to.- Returns:
- organizationId
-
setOrganizationId
-
id
-
getId
The unique identifier of the project.- Returns:
- id
-
getId_JsonNullable
-
setId_JsonNullable
-
setId
-
name
-
getName
Name of the project.- Returns:
- name
-
setName
-
projectRoleAssertion
public BetaProjectServiceCreateProjectRequest projectRoleAssertion(@Nullable Boolean projectRoleAssertion) -
getProjectRoleAssertion
Enable this setting to provide role information to your application. For OpenID Connect, the roles can be requested from the UserInfo endpoint or sent in the ID or Access Token, based on your application's configuration.- Returns:
- projectRoleAssertion
-
setProjectRoleAssertion
-
authorizationRequired
public BetaProjectServiceCreateProjectRequest authorizationRequired(@Nullable Boolean authorizationRequired) -
getAuthorizationRequired
Deny authentication if the user has no authorization assigned to this project. Authorizations to the project without assigned a specific role to the user are allowed.- Returns:
- authorizationRequired
-
setAuthorizationRequired
-
projectAccessRequired
public BetaProjectServiceCreateProjectRequest projectAccessRequired(@Nullable Boolean projectAccessRequired) -
getProjectAccessRequired
Before a user can be authenticated, it is verified that their affiliated organization has been granted access to this project. Authentication is not permitted for users from unauthorized organizations.- Returns:
- projectAccessRequired
-
setProjectAccessRequired
-
privateLabelingSetting
public BetaProjectServiceCreateProjectRequest privateLabelingSetting(@Nullable BetaProjectServicePrivateLabelingSetting privateLabelingSetting) -
getPrivateLabelingSetting
Get privateLabelingSetting- Returns:
- privateLabelingSetting
-
setPrivateLabelingSetting
public void setPrivateLabelingSetting(@Nullable BetaProjectServicePrivateLabelingSetting privateLabelingSetting) -
admins
public BetaProjectServiceCreateProjectRequest admins(@Nullable List<BetaProjectServiceAdmin> admins) -
addAdminsItem
-
getAdmins
List of users and Project Member roles (PROJECT_OWNER, by default) to be assigned to those users.- Returns:
- admins
-
setAdmins
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-