Package com.zitadel.model
Class BetaProjectServiceRemoveProjectRoleRequest
java.lang.Object
com.zitadel.model.BetaProjectServiceRemoveProjectRoleRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class BetaProjectServiceRemoveProjectRoleRequest
extends Object
BetaProjectServiceRemoveProjectRoleRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanID of the project.The key is the only relevant attribute for ZITADEL regarding the authorization checks.inthashCode()voidsetProjectId(String projectId) voidsetRoleKey(String roleKey) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
JSON_PROPERTY_ROLE_KEY
- See Also:
-
-
Constructor Details
-
BetaProjectServiceRemoveProjectRoleRequest
public BetaProjectServiceRemoveProjectRoleRequest()
-
-
Method Details
-
projectId
-
getProjectId
ID of the project.- Returns:
- projectId
-
setProjectId
-
roleKey
-
getRoleKey
The key is the only relevant attribute for ZITADEL regarding the authorization checks.- Returns:
- roleKey
-
setRoleKey
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-