Package com.zitadel.model
Class BetaProjectServiceUpdateProjectRequest
java.lang.Object
com.zitadel.model.BetaProjectServiceUpdateProjectRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class BetaProjectServiceUpdateProjectRequest
extends Object
BetaProjectServiceUpdateProjectRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanWhen enabled ZITADEL will check if the organization of the user, that is trying to log in, has a grant to this project.org.openapitools.jackson.nullable.JsonNullable<Boolean>getId()Get idgetName()Name of the project.org.openapitools.jackson.nullable.JsonNullable<String>Get privateLabelingSettingEnable this setting to have role information included in the user info endpoint.org.openapitools.jackson.nullable.JsonNullable<Boolean>When enabled ZITADEL will check if a user has a role of this project assigned when login into an application of this project.org.openapitools.jackson.nullable.JsonNullable<Boolean>inthashCode()hasProjectCheck(Boolean hasProjectCheck) privateLabelingSetting(BetaProjectServicePrivateLabelingSetting privateLabelingSetting) projectRoleAssertion(Boolean projectRoleAssertion) projectRoleCheck(Boolean projectRoleCheck) voidsetHasProjectCheck(Boolean hasProjectCheck) voidsetHasProjectCheck_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> hasProjectCheck) voidvoidvoidsetName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> name) voidsetPrivateLabelingSetting(BetaProjectServicePrivateLabelingSetting privateLabelingSetting) voidsetProjectRoleAssertion(Boolean projectRoleAssertion) voidsetProjectRoleAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> projectRoleAssertion) voidsetProjectRoleCheck(Boolean projectRoleCheck) voidsetProjectRoleCheck_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> projectRoleCheck) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_ID
- See Also:
-
JSON_PROPERTY_NAME
- See Also:
-
JSON_PROPERTY_PROJECT_ROLE_ASSERTION
- See Also:
-
JSON_PROPERTY_PROJECT_ROLE_CHECK
- See Also:
-
JSON_PROPERTY_HAS_PROJECT_CHECK
- See Also:
-
JSON_PROPERTY_PRIVATE_LABELING_SETTING
- See Also:
-
-
Constructor Details
-
BetaProjectServiceUpdateProjectRequest
public BetaProjectServiceUpdateProjectRequest()
-
-
Method Details
-
id
-
getId
Get id- Returns:
- id
-
setId
-
name
-
getName
Name of the project.- Returns:
- name
-
getName_JsonNullable
-
setName_JsonNullable
-
setName
-
projectRoleAssertion
public BetaProjectServiceUpdateProjectRequest projectRoleAssertion(@Nullable Boolean projectRoleAssertion) -
getProjectRoleAssertion
Enable this setting to have role information included in the user info endpoint. It is also dependent on your application settings to include it in tokens and other types.- Returns:
- projectRoleAssertion
-
getProjectRoleAssertion_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<Boolean> getProjectRoleAssertion_JsonNullable() -
setProjectRoleAssertion_JsonNullable
public void setProjectRoleAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> projectRoleAssertion) -
setProjectRoleAssertion
-
projectRoleCheck
-
getProjectRoleCheck
When enabled ZITADEL will check if a user has a role of this project assigned when login into an application of this project.- Returns:
- projectRoleCheck
-
getProjectRoleCheck_JsonNullable
-
setProjectRoleCheck_JsonNullable
public void setProjectRoleCheck_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> projectRoleCheck) -
setProjectRoleCheck
-
hasProjectCheck
-
getHasProjectCheck
When enabled ZITADEL will check if the organization of the user, that is trying to log in, has a grant to this project.- Returns:
- hasProjectCheck
-
getHasProjectCheck_JsonNullable
-
setHasProjectCheck_JsonNullable
public void setHasProjectCheck_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> hasProjectCheck) -
setHasProjectCheck
-
privateLabelingSetting
public BetaProjectServiceUpdateProjectRequest privateLabelingSetting(@Nullable BetaProjectServicePrivateLabelingSetting privateLabelingSetting) -
getPrivateLabelingSetting
Get privateLabelingSetting- Returns:
- privateLabelingSetting
-
setPrivateLabelingSetting
public void setPrivateLabelingSetting(@Nullable BetaProjectServicePrivateLabelingSetting privateLabelingSetting) -
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-