Class BetaProjectServiceUpdateProjectRoleRequest

java.lang.Object
com.zitadel.model.BetaProjectServiceUpdateProjectRoleRequest

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class BetaProjectServiceUpdateProjectRoleRequest extends Object
BetaProjectServiceUpdateProjectRoleRequest
  • Field Details

  • Constructor Details

    • BetaProjectServiceUpdateProjectRoleRequest

      public BetaProjectServiceUpdateProjectRoleRequest()
  • Method Details

    • projectId

    • getProjectId

      @Nullable public String getProjectId()
      ID of the project.
      Returns:
      projectId
    • setProjectId

      public void setProjectId(@Nullable String projectId)
    • roleKey

    • getRoleKey

      @Nullable public String getRoleKey()
      The key is the only relevant attribute for ZITADEL regarding the authorization checks.
      Returns:
      roleKey
    • setRoleKey

      public void setRoleKey(@Nullable String roleKey)
    • displayName

    • getDisplayName

      @Nullable public String getDisplayName()
      Name displayed for the role.
      Returns:
      displayName
    • getDisplayName_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getDisplayName_JsonNullable()
    • setDisplayName_JsonNullable

      public void setDisplayName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> displayName)
    • setDisplayName

      public void setDisplayName(@Nullable String displayName)
    • group

    • getGroup

      @Nullable public String getGroup()
      The group is only used for display purposes. That you have better handling, like giving all the roles from a group to a user.
      Returns:
      group
    • getGroup_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getGroup_JsonNullable()
    • setGroup_JsonNullable

      public void setGroup_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> group)
    • setGroup

      public void setGroup(@Nullable String group)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string