Class BetaSessionServiceCreateSessionRequest

java.lang.Object
com.zitadel.model.BetaSessionServiceCreateSessionRequest

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class BetaSessionServiceCreateSessionRequest extends Object
BetaSessionServiceCreateSessionRequest
  • Field Details

  • Constructor Details

    • BetaSessionServiceCreateSessionRequest

      public BetaSessionServiceCreateSessionRequest()
  • Method Details

    • checks

    • getChecks

      @Nullable public BetaSessionServiceChecks getChecks()
      Get checks
      Returns:
      checks
    • setChecks

      public void setChecks(@Nullable BetaSessionServiceChecks checks)
    • metadata

      public BetaSessionServiceCreateSessionRequest metadata(@Nullable Map<String,byte[]> metadata)
    • putMetadataItem

      public BetaSessionServiceCreateSessionRequest putMetadataItem(String key, byte[] metadataItem)
    • getMetadata

      @Nullable public Map<String,byte[]> getMetadata()
      Get metadata
      Returns:
      metadata
    • setMetadata

      public void setMetadata(@Nullable Map<String,byte[]> metadata)
    • challenges

    • getChallenges

      Get challenges
      Returns:
      challenges
    • setChallenges

      public void setChallenges(@Nullable BetaSessionServiceRequestChallenges challenges)
    • userAgent

    • getUserAgent

      @Nullable public BetaSessionServiceUserAgent getUserAgent()
      Get userAgent
      Returns:
      userAgent
    • setUserAgent

      public void setUserAgent(@Nullable BetaSessionServiceUserAgent userAgent)
    • lifetime

    • getLifetime

      @Nullable public String getLifetime()
      A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like \"day\" or \"month\". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +-10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = ...; Timestamp end = ...; Duration duration = ...; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds += 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos += 1000000000; } Example 2: Compute Timestamp from Timestamp + Duration in pseudo code. Timestamp start = ...; Duration duration = ...; Timestamp end = ...; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos += 1000000000; } else if (end.nanos >= 1000000000) { end.seconds += 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix \"s\" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as \"3s\", while 3 seconds and 1 nanosecond should be expressed in JSON format as \"3.000000001s\", and 3 seconds and 1 microsecond should be expressed in JSON format as \"3.000001s\".
      Returns:
      lifetime
    • setLifetime

      public void setLifetime(@Nullable String lifetime)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string