Package com.zitadel.model
Class BetaUserServiceAddHumanUserRequest
java.lang.Object
com.zitadel.model.BetaUserServiceAddHumanUserRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class BetaUserServiceAddHumanUserRequest
extends Object
BetaUserServiceAddHumanUserRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddIdpLinksItem(BetaUserServiceIDPLink idpLinksItem) addMetadataItem(BetaUserServiceSetMetadataEntry metadataItem) booleangetEmail()Get emailGet hashedPasswordGet idpLinksGet metadataGet organizationGet passwordgetPhone()Get phoneGet profileAn Implementation of RFC 6238 is used, with HMAC-SHA-1 and time-step of 30 seconds.org.openapitools.jackson.nullable.JsonNullable<String>optionally set your own id unique for the user.org.openapitools.jackson.nullable.JsonNullable<String>optionally set a unique username, if none is provided the email will be used.org.openapitools.jackson.nullable.JsonNullable<String>inthashCode()hashedPassword(BetaUserServiceHashedPassword hashedPassword) idpLinks(List<BetaUserServiceIDPLink> idpLinks) metadata(List<BetaUserServiceSetMetadataEntry> metadata) organization(BetaUserServiceOrganization organization) password(BetaUserServicePassword password) profile(BetaUserServiceSetHumanProfile profile) voidvoidsetHashedPassword(BetaUserServiceHashedPassword hashedPassword) voidsetIdpLinks(List<BetaUserServiceIDPLink> idpLinks) voidsetMetadata(List<BetaUserServiceSetMetadataEntry> metadata) voidsetOrganization(BetaUserServiceOrganization organization) voidsetPassword(BetaUserServicePassword password) voidvoidsetProfile(BetaUserServiceSetHumanProfile profile) voidsetTotpSecret(String totpSecret) voidsetTotpSecret_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> totpSecret) voidvoidsetUserId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> userId) voidsetUsername(String username) voidsetUsername_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> username) toString()totpSecret(String totpSecret) Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_USER_ID
- See Also:
-
JSON_PROPERTY_USERNAME
- See Also:
-
JSON_PROPERTY_ORGANIZATION
- See Also:
-
JSON_PROPERTY_PROFILE
- See Also:
-
JSON_PROPERTY_EMAIL
- See Also:
-
JSON_PROPERTY_PHONE
- See Also:
-
JSON_PROPERTY_METADATA
- See Also:
-
JSON_PROPERTY_IDP_LINKS
- See Also:
-
JSON_PROPERTY_TOTP_SECRET
- See Also:
-
JSON_PROPERTY_HASHED_PASSWORD
- See Also:
-
JSON_PROPERTY_PASSWORD
- See Also:
-
-
Constructor Details
-
BetaUserServiceAddHumanUserRequest
public BetaUserServiceAddHumanUserRequest()
-
-
Method Details
-
userId
-
getUserId
optionally set your own id unique for the user.- Returns:
- userId
-
getUserId_JsonNullable
-
setUserId_JsonNullable
-
setUserId
-
username
-
getUsername
optionally set a unique username, if none is provided the email will be used.- Returns:
- username
-
getUsername_JsonNullable
-
setUsername_JsonNullable
public void setUsername_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> username) -
setUsername
-
organization
public BetaUserServiceAddHumanUserRequest organization(@Nullable BetaUserServiceOrganization organization) -
getOrganization
Get organization- Returns:
- organization
-
setOrganization
-
profile
-
getProfile
Get profile- Returns:
- profile
-
setProfile
-
email
-
getEmail
Get email- Returns:
-
setEmail
-
phone
-
getPhone
Get phone- Returns:
- phone
-
setPhone
-
metadata
public BetaUserServiceAddHumanUserRequest metadata(@Nullable List<BetaUserServiceSetMetadataEntry> metadata) -
addMetadataItem
public BetaUserServiceAddHumanUserRequest addMetadataItem(BetaUserServiceSetMetadataEntry metadataItem) -
getMetadata
Get metadata- Returns:
- metadata
-
setMetadata
-
idpLinks
-
addIdpLinksItem
-
getIdpLinks
Get idpLinks- Returns:
- idpLinks
-
setIdpLinks
-
totpSecret
-
getTotpSecret
An Implementation of RFC 6238 is used, with HMAC-SHA-1 and time-step of 30 seconds. Currently no other options are supported, and if anything different is used the validation will fail.- Returns:
- totpSecret
-
getTotpSecret_JsonNullable
-
setTotpSecret_JsonNullable
public void setTotpSecret_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> totpSecret) -
setTotpSecret
-
hashedPassword
public BetaUserServiceAddHumanUserRequest hashedPassword(@Nullable BetaUserServiceHashedPassword hashedPassword) -
getHashedPassword
Get hashedPassword- Returns:
- hashedPassword
-
setHashedPassword
-
password
-
getPassword
Get password- Returns:
- password
-
setPassword
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-