Package com.zitadel.model
Class BetaUserServiceFormData
java.lang.Object
com.zitadel.model.BetaUserServiceFormData
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class BetaUserServiceFormData
extends Object
BetaUserServiceFormData
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanThe form fields to be submitted.getUrl()The URL to which the form should be submitted using the POST method.inthashCode()putFieldsItem(String key, String fieldsItem) voidvoidtoString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_URL
- See Also:
-
JSON_PROPERTY_FIELDS
- See Also:
-
-
Constructor Details
-
BetaUserServiceFormData
public BetaUserServiceFormData()
-
-
Method Details
-
url
-
getUrl
The URL to which the form should be submitted using the POST method.- Returns:
- url
-
setUrl
-
fields
-
putFieldsItem
-
getFields
The form fields to be submitted. Each field is represented as a key-value pair, where the key is the field / input name and the value is the field / input value. All fields need to be submitted as is and as input type \"text\".- Returns:
- fields
-
setFields
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-