Class BetaWebKeyServiceAny

java.lang.Object
java.util.AbstractMap<K,V>
java.util.HashMap<String,Object>
com.zitadel.model.BetaWebKeyServiceAny
All Implemented Interfaces:
Serializable, Cloneable, Map<String,Object>

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class BetaWebKeyServiceAny extends HashMap<String,Object>
Contains an arbitrary serialized message along with a @type that describes the type of the serialized message, with an additional debug field for ConnectRPC error details.
See Also:
  • Field Details

  • Constructor Details

    • BetaWebKeyServiceAny

      public BetaWebKeyServiceAny()
  • Method Details

    • type

    • getType

      @Nullable public String getType()
      A URL that acts as a globally unique identifier for the type of the serialized message. For example: `type.googleapis.com/google.rpc.ErrorInfo`. This is used to determine the schema of the data in the `value` field and is the discriminator for the `debug` field.
      Returns:
      type
    • setType

      public void setType(@Nullable String type)
    • value

      public BetaWebKeyServiceAny value(@Nullable File value)
    • getValue

      @Nullable public File getValue()
      The Protobuf message, serialized as bytes and base64-encoded. The specific message type is identified by the `type` field.
      Returns:
      value
    • setValue

      public void setValue(@Nullable File value)
    • debug

      public BetaWebKeyServiceAny debug(@Nullable Object debug)
    • getDebug

      @Nullable public Object getDebug()
      Deserialized error detail payload. The 'type' field indicates the schema. This field is for easier debugging and should not be relied upon for application logic.
      Returns:
      debug
    • getDebug_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<Object> getDebug_JsonNullable()
    • setDebug_JsonNullable

      public void setDebug_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Object> debug)
    • setDebug

      public void setDebug(@Nullable Object debug)
    • equals

      public boolean equals(Object o)
      Specified by:
      equals in interface Map<String,Object>
      Overrides:
      equals in class AbstractMap<String,Object>
    • hashCode

      public int hashCode()
      Specified by:
      hashCode in interface Map<String,Object>
      Overrides:
      hashCode in class AbstractMap<String,Object>
    • toString

      public String toString()
      Overrides:
      toString in class AbstractMap<String,Object>
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string