Package com.zitadel.model
Class InstanceServiceAddCustomDomainRequest
java.lang.Object
com.zitadel.model.InstanceServiceAddCustomDomainRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class InstanceServiceAddCustomDomainRequest
extends Object
InstanceServiceAddCustomDomainRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncustomDomain(String customDomain) booleanCustom domain to add to the instance.InstanceID is the unique ID of the instance to which the domain will be added.inthashCode()instanceId(String instanceId) voidsetCustomDomain(String customDomain) voidsetInstanceId(String instanceId) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_INSTANCE_ID
- See Also:
-
JSON_PROPERTY_CUSTOM_DOMAIN
- See Also:
-
-
Constructor Details
-
InstanceServiceAddCustomDomainRequest
public InstanceServiceAddCustomDomainRequest()
-
-
Method Details
-
instanceId
-
getInstanceId
InstanceID is the unique ID of the instance to which the domain will be added.- Returns:
- instanceId
-
setInstanceId
-
customDomain
-
getCustomDomain
Custom domain to add to the instance. Must be a valid domain name. Once the domain is added, it will be used to route requests to this instance.- Returns:
- customDomain
-
setCustomDomain
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-