Package com.zitadel.model
Class InstanceServiceGetInstanceRequest
java.lang.Object
com.zitadel.model.InstanceServiceGetInstanceRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class InstanceServiceGetInstanceRequest
extends Object
InstanceServiceGetInstanceRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanInstanceID is the unique ID of the instance to be retrieved.inthashCode()instanceId(String instanceId) voidsetInstanceId(String instanceId) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_INSTANCE_ID
- See Also:
-
-
Constructor Details
-
InstanceServiceGetInstanceRequest
public InstanceServiceGetInstanceRequest()
-
-
Method Details
-
instanceId
-
getInstanceId
InstanceID is the unique ID of the instance to be retrieved. If not set, the instance in the current context (e.g. identified by the host header) will be returned. If an ID is set, the caller must have additional permissions.- Returns:
- instanceId
-
setInstanceId
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-