Package com.zitadel.model
Class InstanceServiceRemoveCustomDomainRequest
java.lang.Object
com.zitadel.model.InstanceServiceRemoveCustomDomainRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class InstanceServiceRemoveCustomDomainRequest
extends Object
InstanceServiceRemoveCustomDomainRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncustomDomain(String customDomain) booleanCustomDomain is the the domain to remove from the instance.InstanceID is the unique ID of the instance from which the domain will be removed.inthashCode()instanceId(String instanceId) voidsetCustomDomain(String customDomain) voidsetInstanceId(String instanceId) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_INSTANCE_ID
- See Also:
-
JSON_PROPERTY_CUSTOM_DOMAIN
- See Also:
-
-
Constructor Details
-
InstanceServiceRemoveCustomDomainRequest
public InstanceServiceRemoveCustomDomainRequest()
-
-
Method Details
-
instanceId
-
getInstanceId
InstanceID is the unique ID of the instance from which the domain will be removed.- Returns:
- instanceId
-
setInstanceId
-
customDomain
-
getCustomDomain
CustomDomain is the the domain to remove from the instance.- Returns:
- customDomain
-
setCustomDomain
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-