Package com.zitadel.model
Class InstanceServiceUpdateInstanceRequest
java.lang.Object
com.zitadel.model.InstanceServiceUpdateInstanceRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class InstanceServiceUpdateInstanceRequest
extends Object
InstanceServiceUpdateInstanceRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanInstanceID is the unique ID of the instance to be updated.InstanceName is the new name of the instance to be set.inthashCode()instanceId(String instanceId) instanceName(String instanceName) voidsetInstanceId(String instanceId) voidsetInstanceName(String instanceName) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_INSTANCE_ID
- See Also:
-
JSON_PROPERTY_INSTANCE_NAME
- See Also:
-
-
Constructor Details
-
InstanceServiceUpdateInstanceRequest
public InstanceServiceUpdateInstanceRequest()
-
-
Method Details
-
instanceId
-
getInstanceId
InstanceID is the unique ID of the instance to be updated. If not set, the instance in the current context (e.g. identified by the host header) will be changed. If an ID is set, the caller must have additional permissions.- Returns:
- instanceId
-
setInstanceId
-
instanceName
-
getInstanceName
InstanceName is the new name of the instance to be set.- Returns:
- instanceName
-
setInstanceName
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-