Package com.zitadel.model
Class ProjectServiceAddProjectRoleRequest
java.lang.Object
com.zitadel.model.ProjectServiceAddProjectRoleRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ProjectServiceAddProjectRoleRequest
extends Object
ProjectServiceAddProjectRoleRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiondisplayName(String displayName) booleanDisplayName is a human readable name for the role, which might be displayed to users.getGroup()Group allows grouping roles for display purposes.org.openapitools.jackson.nullable.JsonNullable<String>ProjectID is the unique identifier of the project.RoleKey identifies the role.inthashCode()voidsetDisplayName(String displayName) voidvoidsetGroup_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> group) voidsetProjectId(String projectId) voidsetRoleKey(String roleKey) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
JSON_PROPERTY_ROLE_KEY
- See Also:
-
JSON_PROPERTY_DISPLAY_NAME
- See Also:
-
JSON_PROPERTY_GROUP
- See Also:
-
-
Constructor Details
-
ProjectServiceAddProjectRoleRequest
public ProjectServiceAddProjectRoleRequest()
-
-
Method Details
-
projectId
-
getProjectId
ProjectID is the unique identifier of the project.- Returns:
- projectId
-
setProjectId
-
roleKey
-
getRoleKey
RoleKey identifies the role. It's the only relevant attribute for ZITADEL and will be used for authorization checks and as claim in tokens and user info responses.- Returns:
- roleKey
-
setRoleKey
-
displayName
-
getDisplayName
DisplayName is a human readable name for the role, which might be displayed to users.- Returns:
- displayName
-
setDisplayName
-
group
-
getGroup
Group allows grouping roles for display purposes. Zitadel will not handle it in any way. It can be used to group roles in a UI to allow easier management for administrators. This attribute is not to be confused with groups as a collection of users.- Returns:
- group
-
getGroup_JsonNullable
-
setGroup_JsonNullable
-
setGroup
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-