Package com.zitadel.model
Class ProjectServiceCreateProjectRequest
java.lang.Object
com.zitadel.model.ProjectServiceCreateProjectRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ProjectServiceCreateProjectRequest
extends Object
ProjectServiceCreateProjectRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionauthorizationRequired(Boolean authorizationRequired) booleanAuthorizationRequired is a boolean flag that can be enabled to check if a user has an authorization to use this project assigned when login into an application of this project.getName()Name of the project.OrganizationID is the unique identifier of the organization the project belongs to.Get privateLabelingSettingProjectAccessRequired is a boolean flag that can be enabled to check if the organization of the user, that is trying to log in, has access to this project (either owns the project or is granted).ProjectID is the unique identifier of the new project.org.openapitools.jackson.nullable.JsonNullable<String>ProjectRoleAssertion is a setting that can be enabled to have role information included in the user info endpoint.inthashCode()organizationId(String organizationId) privateLabelingSetting(ProjectServicePrivateLabelingSetting privateLabelingSetting) projectAccessRequired(Boolean projectAccessRequired) projectRoleAssertion(Boolean projectRoleAssertion) voidsetAuthorizationRequired(Boolean authorizationRequired) voidvoidsetOrganizationId(String organizationId) voidsetPrivateLabelingSetting(ProjectServicePrivateLabelingSetting privateLabelingSetting) voidsetProjectAccessRequired(Boolean projectAccessRequired) voidsetProjectId(String projectId) voidsetProjectId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> projectId) voidsetProjectRoleAssertion(Boolean projectRoleAssertion) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_ORGANIZATION_ID
- See Also:
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
JSON_PROPERTY_NAME
- See Also:
-
JSON_PROPERTY_PROJECT_ROLE_ASSERTION
- See Also:
-
JSON_PROPERTY_AUTHORIZATION_REQUIRED
- See Also:
-
JSON_PROPERTY_PROJECT_ACCESS_REQUIRED
- See Also:
-
JSON_PROPERTY_PRIVATE_LABELING_SETTING
- See Also:
-
-
Constructor Details
-
ProjectServiceCreateProjectRequest
public ProjectServiceCreateProjectRequest()
-
-
Method Details
-
organizationId
-
getOrganizationId
OrganizationID is the unique identifier of the organization the project belongs to.- Returns:
- organizationId
-
setOrganizationId
-
projectId
-
getProjectId
ProjectID is the unique identifier of the new project. This field is optional. If omitted, the system will generate a unique ID for you. This is the recommended way. The generated ID will be returned in the response.- Returns:
- projectId
-
getProjectId_JsonNullable
-
setProjectId_JsonNullable
public void setProjectId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> projectId) -
setProjectId
-
name
-
getName
Name of the project. This might be presented to users, e.g. in sign-in flows.- Returns:
- name
-
setName
-
projectRoleAssertion
public ProjectServiceCreateProjectRequest projectRoleAssertion(@Nullable Boolean projectRoleAssertion) -
getProjectRoleAssertion
ProjectRoleAssertion is a setting that can be enabled to have role information included in the user info endpoint. It is also dependent on your application settings to include it in tokens and other types.- Returns:
- projectRoleAssertion
-
setProjectRoleAssertion
-
authorizationRequired
public ProjectServiceCreateProjectRequest authorizationRequired(@Nullable Boolean authorizationRequired) -
getAuthorizationRequired
AuthorizationRequired is a boolean flag that can be enabled to check if a user has an authorization to use this project assigned when login into an application of this project.- Returns:
- authorizationRequired
-
setAuthorizationRequired
-
projectAccessRequired
public ProjectServiceCreateProjectRequest projectAccessRequired(@Nullable Boolean projectAccessRequired) -
getProjectAccessRequired
ProjectAccessRequired is a boolean flag that can be enabled to check if the organization of the user, that is trying to log in, has access to this project (either owns the project or is granted).- Returns:
- projectAccessRequired
-
setProjectAccessRequired
-
privateLabelingSetting
public ProjectServiceCreateProjectRequest privateLabelingSetting(@Nullable ProjectServicePrivateLabelingSetting privateLabelingSetting) -
getPrivateLabelingSetting
Get privateLabelingSetting- Returns:
- privateLabelingSetting
-
setPrivateLabelingSetting
public void setPrivateLabelingSetting(@Nullable ProjectServicePrivateLabelingSetting privateLabelingSetting) -
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-