Package com.zitadel.model
Class ProjectServiceGetProjectRequest
java.lang.Object
com.zitadel.model.ProjectServiceGetProjectRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ProjectServiceGetProjectRequest
extends Object
ProjectServiceGetProjectRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanProjectID is the unique identifier of the project to be retrieved.inthashCode()voidsetProjectId(String projectId) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
-
Constructor Details
-
ProjectServiceGetProjectRequest
public ProjectServiceGetProjectRequest()
-
-
Method Details
-
projectId
-
getProjectId
ProjectID is the unique identifier of the project to be retrieved.- Returns:
- projectId
-
setProjectId
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-