Class ProjectServiceProject

java.lang.Object
com.zitadel.model.ProjectServiceProject

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class ProjectServiceProject extends Object
ProjectServiceProject
  • Field Details

  • Constructor Details

    • ProjectServiceProject

      public ProjectServiceProject()
  • Method Details

    • projectId

      public ProjectServiceProject projectId(@Nullable String projectId)
    • getProjectId

      @Nullable public String getProjectId()
      ProjectID is the unique identifier of the project.
      Returns:
      projectId
    • setProjectId

      public void setProjectId(@Nullable String projectId)
    • organizationId

      public ProjectServiceProject organizationId(@Nullable String organizationId)
    • getOrganizationId

      @Nullable public String getOrganizationId()
      OrganizationID is the unique identifier of the organization the project belongs to.
      Returns:
      organizationId
    • setOrganizationId

      public void setOrganizationId(@Nullable String organizationId)
    • creationDate

      public ProjectServiceProject creationDate(@Nullable OffsetDateTime creationDate)
    • getCreationDate

      @Nullable public OffsetDateTime getCreationDate()
      A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are \"smeared\" so that no leap second table is needed for interpretation, using a [24-hour linear smear](https://developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX `time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format. That is, the format is \"{year}-{month}-{day}T{hour}:{min}:{sec}[.{frac_sec}]Z\" where {year} is always expressed using four digits while {month}, {day}, {hour}, {min}, and {sec} are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The \"Z\" suffix indicates the timezone (\"UTC\"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by \"Z\") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, \"2017-01-15T01:30:15.01Z\" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](https://docs.python.org/2/library/time.html#time.strftime) with the time format spec '%Y-%m-%dT%H:%M:%S.%fZ'. Likewise, in Java, one can use the Joda Time's [`ISODateTimeFormat.dateTime()`]( http://joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.
      Returns:
      creationDate
    • setCreationDate

      public void setCreationDate(@Nullable OffsetDateTime creationDate)
    • changeDate

      public ProjectServiceProject changeDate(@Nullable OffsetDateTime changeDate)
    • getChangeDate

      @Nullable public OffsetDateTime getChangeDate()
      A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are \"smeared\" so that no leap second table is needed for interpretation, using a [24-hour linear smear](https://developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX `time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format. That is, the format is \"{year}-{month}-{day}T{hour}:{min}:{sec}[.{frac_sec}]Z\" where {year} is always expressed using four digits while {month}, {day}, {hour}, {min}, and {sec} are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The \"Z\" suffix indicates the timezone (\"UTC\"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by \"Z\") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, \"2017-01-15T01:30:15.01Z\" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](https://docs.python.org/2/library/time.html#time.strftime) with the time format spec '%Y-%m-%dT%H:%M:%S.%fZ'. Likewise, in Java, one can use the Joda Time's [`ISODateTimeFormat.dateTime()`]( http://joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.
      Returns:
      changeDate
    • setChangeDate

      public void setChangeDate(@Nullable OffsetDateTime changeDate)
    • name

    • getName

      @Nullable public String getName()
      Name is the name of the project. This might be presented to users, e.g. in sign-in flows.
      Returns:
      name
    • setName

      public void setName(@Nullable String name)
    • state

    • getState

      Get state
      Returns:
      state
    • setState

      public void setState(@Nullable ProjectServiceProjectState state)
    • projectRoleAssertion

      public ProjectServiceProject projectRoleAssertion(@Nullable Boolean projectRoleAssertion)
    • getProjectRoleAssertion

      @Nullable public Boolean getProjectRoleAssertion()
      ProjectRoleAssertion is a boolean flag that describes if the roles of the user should be added to the token.
      Returns:
      projectRoleAssertion
    • setProjectRoleAssertion

      public void setProjectRoleAssertion(@Nullable Boolean projectRoleAssertion)
    • authorizationRequired

      public ProjectServiceProject authorizationRequired(@Nullable Boolean authorizationRequired)
    • getAuthorizationRequired

      @Nullable public Boolean getAuthorizationRequired()
      AuthorizationRequired is a boolean flag that can be enabled to check if a user has an authorization to use this project assigned when login into an application of this project.
      Returns:
      authorizationRequired
    • setAuthorizationRequired

      public void setAuthorizationRequired(@Nullable Boolean authorizationRequired)
    • projectAccessRequired

      public ProjectServiceProject projectAccessRequired(@Nullable Boolean projectAccessRequired)
    • getProjectAccessRequired

      @Nullable public Boolean getProjectAccessRequired()
      ProjectAccessRequired is a boolean flag that can be enabled to check if the organization of the user, that is trying to log in, has access to this project (either owns the project or is granted).
      Returns:
      projectAccessRequired
    • setProjectAccessRequired

      public void setProjectAccessRequired(@Nullable Boolean projectAccessRequired)
    • privateLabelingSetting

      public ProjectServiceProject privateLabelingSetting(@Nullable ProjectServicePrivateLabelingSetting privateLabelingSetting)
    • getPrivateLabelingSetting

      @Nullable public ProjectServicePrivateLabelingSetting getPrivateLabelingSetting()
      Get privateLabelingSetting
      Returns:
      privateLabelingSetting
    • setPrivateLabelingSetting

      public void setPrivateLabelingSetting(@Nullable ProjectServicePrivateLabelingSetting privateLabelingSetting)
    • grantedOrganizationId

      public ProjectServiceProject grantedOrganizationId(@Nullable String grantedOrganizationId)
    • getGrantedOrganizationId

      @Nullable public String getGrantedOrganizationId()
      GrantedOrganizationID is the ID of the organization the project is granted to. In case the project is not granted, this field is unset.
      Returns:
      grantedOrganizationId
    • getGrantedOrganizationId_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getGrantedOrganizationId_JsonNullable()
    • setGrantedOrganizationId_JsonNullable

      public void setGrantedOrganizationId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> grantedOrganizationId)
    • setGrantedOrganizationId

      public void setGrantedOrganizationId(@Nullable String grantedOrganizationId)
    • grantedOrganizationName

      public ProjectServiceProject grantedOrganizationName(@Nullable String grantedOrganizationName)
    • getGrantedOrganizationName

      @Nullable public String getGrantedOrganizationName()
      GrantedOrganizationName is the name of the organization the project is granted to. In case the project is not granted, this field is unset.
      Returns:
      grantedOrganizationName
    • getGrantedOrganizationName_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getGrantedOrganizationName_JsonNullable()
    • setGrantedOrganizationName_JsonNullable

      public void setGrantedOrganizationName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> grantedOrganizationName)
    • setGrantedOrganizationName

      public void setGrantedOrganizationName(@Nullable String grantedOrganizationName)
    • grantedState

    • getGrantedState

      @Nullable public ProjectServiceGrantedProjectState getGrantedState()
      Get grantedState
      Returns:
      grantedState
    • setGrantedState

      public void setGrantedState(@Nullable ProjectServiceGrantedProjectState grantedState)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string