Package com.zitadel.model
Class ProjectServiceProjectRoleKeyFilter
java.lang.Object
com.zitadel.model.ProjectServiceProjectRoleKeyFilter
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ProjectServiceProjectRoleKeyFilter
extends Object
ProjectServiceProjectRoleKeyFilter
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleangetKey()The key of the project role to query for.Get methodinthashCode()method(ProjectServiceTextFilterMethod method) voidvoidtoString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_KEY
- See Also:
-
JSON_PROPERTY_METHOD
- See Also:
-
-
Constructor Details
-
ProjectServiceProjectRoleKeyFilter
public ProjectServiceProjectRoleKeyFilter()
-
-
Method Details
-
key
-
getKey
The key of the project role to query for.- Returns:
- key
-
setKey
-
method
-
getMethod
Get method- Returns:
- method
-
setMethod
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-