Class ProjectServiceRemoveProjectRoleRequest

java.lang.Object
com.zitadel.model.ProjectServiceRemoveProjectRoleRequest

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class ProjectServiceRemoveProjectRoleRequest extends Object
ProjectServiceRemoveProjectRoleRequest
  • Field Details

  • Constructor Details

    • ProjectServiceRemoveProjectRoleRequest

      public ProjectServiceRemoveProjectRoleRequest()
  • Method Details

    • projectId

    • getProjectId

      @Nullable public String getProjectId()
      ProjectID is the unique identifier of the project.
      Returns:
      projectId
    • setProjectId

      public void setProjectId(@Nullable String projectId)
    • roleKey

    • getRoleKey

      @Nullable public String getRoleKey()
      RoleKey is the key of the role to be removed. All dependencies of this role will be removed as well, including project grants and user grants. If the role is not found, the request will return a successful response as the desired state is already achieved.
      Returns:
      roleKey
    • setRoleKey

      public void setRoleKey(@Nullable String roleKey)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string