Class ProjectServiceUpdateProjectGrantRequest

java.lang.Object
com.zitadel.model.ProjectServiceUpdateProjectGrantRequest

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class ProjectServiceUpdateProjectGrantRequest extends Object
ProjectServiceUpdateProjectGrantRequest
  • Field Details

  • Constructor Details

    • ProjectServiceUpdateProjectGrantRequest

      public ProjectServiceUpdateProjectGrantRequest()
  • Method Details

    • projectId

    • getProjectId

      @Nullable public String getProjectId()
      ProjectID is the unique identifier of the project.
      Returns:
      projectId
    • setProjectId

      public void setProjectId(@Nullable String projectId)
    • grantedOrganizationId

      public ProjectServiceUpdateProjectGrantRequest grantedOrganizationId(@Nullable String grantedOrganizationId)
    • getGrantedOrganizationId

      @Nullable public String getGrantedOrganizationId()
      GrantedOrganizationID is the unique identifier of the organization the project was granted to.
      Returns:
      grantedOrganizationId
    • setGrantedOrganizationId

      public void setGrantedOrganizationId(@Nullable String grantedOrganizationId)
    • roleKeys

    • addRoleKeysItem

      public ProjectServiceUpdateProjectGrantRequest addRoleKeysItem(String roleKeysItem)
    • getRoleKeys

      @Nullable public List<String> getRoleKeys()
      RoleKeys is a list of roles to be granted to the organization for self management. The roles are identified by their keys. Any roles not included in this list will be removed from the project grant. If you want to add a role, make sure to include all other existing roles as well. If any previous role is removed, all user grants for this project grant with this role will be removed as well.
      Returns:
      roleKeys
    • setRoleKeys

      public void setRoleKeys(@Nullable List<String> roleKeys)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string