Class ProjectServiceUpdateProjectRequest

java.lang.Object
com.zitadel.model.ProjectServiceUpdateProjectRequest

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class ProjectServiceUpdateProjectRequest extends Object
ProjectServiceUpdateProjectRequest
  • Field Details

  • Constructor Details

    • ProjectServiceUpdateProjectRequest

      public ProjectServiceUpdateProjectRequest()
  • Method Details

    • projectId

      public ProjectServiceUpdateProjectRequest projectId(@Nullable String projectId)
    • getProjectId

      @Nullable public String getProjectId()
      ProjectID is the unique identifier of the project to be updated.
      Returns:
      projectId
    • setProjectId

      public void setProjectId(@Nullable String projectId)
    • name

    • getName

      @Nullable public String getName()
      Name is used to update the name of the project. This field is optional. If omitted, the name will remain unchanged.
      Returns:
      name
    • getName_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getName_JsonNullable()
    • setName_JsonNullable

      public void setName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> name)
    • setName

      public void setName(@Nullable String name)
    • projectRoleAssertion

      public ProjectServiceUpdateProjectRequest projectRoleAssertion(@Nullable Boolean projectRoleAssertion)
    • getProjectRoleAssertion

      @Nullable public Boolean getProjectRoleAssertion()
      ProjectRoleAssertion is a setting that can be enabled to have role information included in the user info endpoint. It is also dependent on your application settings to include it in tokens and other types. If omitted, the setting will remain unchanged.
      Returns:
      projectRoleAssertion
    • getProjectRoleAssertion_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<Boolean> getProjectRoleAssertion_JsonNullable()
    • setProjectRoleAssertion_JsonNullable

      public void setProjectRoleAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> projectRoleAssertion)
    • setProjectRoleAssertion

      public void setProjectRoleAssertion(@Nullable Boolean projectRoleAssertion)
    • authorizationRequired

      public ProjectServiceUpdateProjectRequest authorizationRequired(@Nullable Boolean authorizationRequired)
    • getAuthorizationRequired

      @Nullable public Boolean getAuthorizationRequired()
      AuthorizationRequired is a boolean flag that can be enabled to check if a user has a role of this project assigned when logging into an application of this project. If omitted, the setting will remain unchanged.
      Returns:
      authorizationRequired
    • getAuthorizationRequired_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<Boolean> getAuthorizationRequired_JsonNullable()
    • setAuthorizationRequired_JsonNullable

      public void setAuthorizationRequired_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> authorizationRequired)
    • setAuthorizationRequired

      public void setAuthorizationRequired(@Nullable Boolean authorizationRequired)
    • projectAccessRequired

      public ProjectServiceUpdateProjectRequest projectAccessRequired(@Nullable Boolean projectAccessRequired)
    • getProjectAccessRequired

      @Nullable public Boolean getProjectAccessRequired()
      ProjectAccessRequired is a boolean flag that can be enabled to check if the organization of the user has a grant to this project. If omitted, the setting will remain unchanged.
      Returns:
      projectAccessRequired
    • getProjectAccessRequired_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<Boolean> getProjectAccessRequired_JsonNullable()
    • setProjectAccessRequired_JsonNullable

      public void setProjectAccessRequired_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> projectAccessRequired)
    • setProjectAccessRequired

      public void setProjectAccessRequired(@Nullable Boolean projectAccessRequired)
    • privateLabelingSetting

      public ProjectServiceUpdateProjectRequest privateLabelingSetting(@Nullable ProjectServicePrivateLabelingSetting privateLabelingSetting)
    • getPrivateLabelingSetting

      @Nullable public ProjectServicePrivateLabelingSetting getPrivateLabelingSetting()
      Get privateLabelingSetting
      Returns:
      privateLabelingSetting
    • setPrivateLabelingSetting

      public void setPrivateLabelingSetting(@Nullable ProjectServicePrivateLabelingSetting privateLabelingSetting)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string