Class ProjectServiceUpdateProjectRoleRequest

java.lang.Object
com.zitadel.model.ProjectServiceUpdateProjectRoleRequest

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class ProjectServiceUpdateProjectRoleRequest extends Object
ProjectServiceUpdateProjectRoleRequest
  • Field Details

  • Constructor Details

    • ProjectServiceUpdateProjectRoleRequest

      public ProjectServiceUpdateProjectRoleRequest()
  • Method Details

    • projectId

    • getProjectId

      @Nullable public String getProjectId()
      ProjectID is the unique identifier of the project.
      Returns:
      projectId
    • setProjectId

      public void setProjectId(@Nullable String projectId)
    • roleKey

    • getRoleKey

      @Nullable public String getRoleKey()
      RoleKey identifies the role. It's the only relevant attribute for ZITADEL and will be used for authorization checks and as claim in tokens and user info responses. It cannot be changed. If you need a different key, remove the role and create a new one.
      Returns:
      roleKey
    • setRoleKey

      public void setRoleKey(@Nullable String roleKey)
    • displayName

      public ProjectServiceUpdateProjectRoleRequest displayName(@Nullable String displayName)
    • getDisplayName

      @Nullable public String getDisplayName()
      DisplayName is the human readable name for the role, which might be displayed to users. If omitted, the name will remain unchanged.
      Returns:
      displayName
    • getDisplayName_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getDisplayName_JsonNullable()
    • setDisplayName_JsonNullable

      public void setDisplayName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> displayName)
    • setDisplayName

      public void setDisplayName(@Nullable String displayName)
    • group

    • getGroup

      @Nullable public String getGroup()
      Group allows grouping roles for display purposes. Zitadel will not handle it in any way. It can be used to group roles in a UI to allow easier management for administrators. If omitted, the group will remain unchanged. This attribute is not to be confused with groups as a collection of users.
      Returns:
      group
    • getGroup_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getGroup_JsonNullable()
    • setGroup_JsonNullable

      public void setGroup_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> group)
    • setGroup

      public void setGroup(@Nullable String group)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string