Class SessionServiceCheckRecoveryCode

java.lang.Object
com.zitadel.model.SessionServiceCheckRecoveryCode

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class SessionServiceCheckRecoveryCode extends Object
SessionServiceCheckRecoveryCode
  • Field Details

  • Constructor Details

    • SessionServiceCheckRecoveryCode

      public SessionServiceCheckRecoveryCode()
  • Method Details

    • code

    • getCode

      @Nullable public String getCode()
      The Recovery Code of the user to be checked. The code must match the exact code previously generated for the user, including dashes if any. On successful check, the recovery code will be invalidated and cannot be used again.
      Returns:
      code
    • setCode

      public void setCode(@Nullable String code)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string