Package com.zitadel.model
Class SessionServiceCreateSessionResponse
java.lang.Object
com.zitadel.model.SessionServiceCreateSessionResponse
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class SessionServiceCreateSessionResponse
extends Object
SessionServiceCreateSessionResponse
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionchallenges(SessionServiceChallenges challenges) details(SessionServiceDetails details) booleanGet challengesGet detailsUnique identifier of the session.The current token of the session, which is required for using the session as authentication, e.g.when authenticating an OIDC auth request or SAML request.inthashCode()sessionToken(String sessionToken) voidsetChallenges(SessionServiceChallenges challenges) voidsetDetails(SessionServiceDetails details) voidsetSessionId(String sessionId) voidsetSessionToken(String sessionToken) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_DETAILS
- See Also:
-
JSON_PROPERTY_SESSION_ID
- See Also:
-
JSON_PROPERTY_SESSION_TOKEN
- See Also:
-
JSON_PROPERTY_CHALLENGES
- See Also:
-
-
Constructor Details
-
SessionServiceCreateSessionResponse
public SessionServiceCreateSessionResponse()
-
-
Method Details
-
details
-
getDetails
Get details- Returns:
- details
-
setDetails
-
sessionId
-
getSessionId
Unique identifier of the session.- Returns:
- sessionId
-
setSessionId
-
sessionToken
-
getSessionToken
The current token of the session, which is required for using the session as authentication, e.g.when authenticating an OIDC auth request or SAML request. Additionally, the session token can be used as OAuth2 access token to authenticate against the ZITADEL APIs.- Returns:
- sessionToken
-
setSessionToken
-
challenges
public SessionServiceCreateSessionResponse challenges(@Nullable SessionServiceChallenges challenges) -
getChallenges
Get challenges- Returns:
- challenges
-
setChallenges
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-