Package com.zitadel.model
Class SessionServiceSendCode
java.lang.Object
com.zitadel.model.SessionServiceSendCode
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class SessionServiceSendCode
extends Object
SessionServiceSendCode
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanOptionally set a url_template, which will be used in the mail sent by ZITADEL to guide the user to your verification page.org.openapitools.jackson.nullable.JsonNullable<String>inthashCode()voidsetUrlTemplate(String urlTemplate) voidsetUrlTemplate_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> urlTemplate) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.urlTemplate(String urlTemplate)
-
Field Details
-
JSON_PROPERTY_URL_TEMPLATE
- See Also:
-
-
Constructor Details
-
SessionServiceSendCode
public SessionServiceSendCode()
-
-
Method Details
-
urlTemplate
-
getUrlTemplate
Optionally set a url_template, which will be used in the mail sent by ZITADEL to guide the user to your verification page. If no template is set, the default ZITADEL url will be used. The following placeholders can be used: Code, UserID, LoginName, DisplayName, PreferredLanguage, SessionID- Returns:
- urlTemplate
-
getUrlTemplate_JsonNullable
-
setUrlTemplate_JsonNullable
public void setUrlTemplate_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> urlTemplate) -
setUrlTemplate
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-