Package com.zitadel.model
Class SessionServiceUserIDQuery
java.lang.Object
com.zitadel.model.SessionServiceUserIDQuery
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class SessionServiceUserIDQuery
extends Object
SessionServiceUserIDQuery
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleangetId()ID of the user whose sessions are being searched for.inthashCode()voidtoString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_ID
- See Also:
-
-
Constructor Details
-
SessionServiceUserIDQuery
public SessionServiceUserIDQuery()
-
-
Method Details
-
id
-
getId
ID of the user whose sessions are being searched for.- Returns:
- id
-
setId
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-