Package com.zitadel.model
Class UserServiceAddHumanUserRequest
java.lang.Object
com.zitadel.model.UserServiceAddHumanUserRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class UserServiceAddHumanUserRequest
extends Object
UserServiceAddHumanUserRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddIdpLinksItem(UserServiceIDPLink idpLinksItem) addMetadataItem(UserServiceSetMetadataEntry metadataItem) email(UserServiceSetHumanEmail email) booleangetEmail()Get emailGet hashedPasswordGet idpLinksGet metadataGet organizationGet passwordgetPhone()Get phoneGet profileAn Implementation of RFC 6238 is used, with HMAC-SHA-1 and time-step of 30 seconds.org.openapitools.jackson.nullable.JsonNullable<String>optionally set your own id unique for the user.org.openapitools.jackson.nullable.JsonNullable<String>optionally set a unique username, if none is provided the email will be used.org.openapitools.jackson.nullable.JsonNullable<String>inthashCode()hashedPassword(UserServiceHashedPassword hashedPassword) idpLinks(List<UserServiceIDPLink> idpLinks) metadata(List<UserServiceSetMetadataEntry> metadata) organization(UserServiceOrganization organization) password(UserServicePassword password) phone(UserServiceSetHumanPhone phone) profile(UserServiceSetHumanProfile profile) voidsetEmail(UserServiceSetHumanEmail email) voidsetHashedPassword(UserServiceHashedPassword hashedPassword) voidsetIdpLinks(List<UserServiceIDPLink> idpLinks) voidsetMetadata(List<UserServiceSetMetadataEntry> metadata) voidsetOrganization(UserServiceOrganization organization) voidsetPassword(UserServicePassword password) voidsetPhone(UserServiceSetHumanPhone phone) voidsetProfile(UserServiceSetHumanProfile profile) voidsetTotpSecret(String totpSecret) voidsetTotpSecret_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> totpSecret) voidvoidsetUserId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> userId) voidsetUsername(String username) voidsetUsername_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> username) toString()totpSecret(String totpSecret) Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_USER_ID
- See Also:
-
JSON_PROPERTY_USERNAME
- See Also:
-
JSON_PROPERTY_ORGANIZATION
- See Also:
-
JSON_PROPERTY_PROFILE
- See Also:
-
JSON_PROPERTY_EMAIL
- See Also:
-
JSON_PROPERTY_PHONE
- See Also:
-
JSON_PROPERTY_METADATA
- See Also:
-
JSON_PROPERTY_IDP_LINKS
- See Also:
-
JSON_PROPERTY_TOTP_SECRET
- See Also:
-
JSON_PROPERTY_HASHED_PASSWORD
- See Also:
-
JSON_PROPERTY_PASSWORD
- See Also:
-
-
Constructor Details
-
UserServiceAddHumanUserRequest
public UserServiceAddHumanUserRequest()
-
-
Method Details
-
userId
-
getUserId
optionally set your own id unique for the user.- Returns:
- userId
-
getUserId_JsonNullable
-
setUserId_JsonNullable
-
setUserId
-
username
-
getUsername
optionally set a unique username, if none is provided the email will be used.- Returns:
- username
-
getUsername_JsonNullable
-
setUsername_JsonNullable
public void setUsername_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> username) -
setUsername
-
organization
-
getOrganization
Get organization- Returns:
- organization
-
setOrganization
-
profile
-
getProfile
Get profile- Returns:
- profile
-
setProfile
-
email
-
getEmail
Get email- Returns:
-
setEmail
-
phone
-
getPhone
Get phone- Returns:
- phone
-
setPhone
-
metadata
public UserServiceAddHumanUserRequest metadata(@Nullable List<UserServiceSetMetadataEntry> metadata) -
addMetadataItem
-
getMetadata
Get metadata- Returns:
- metadata
-
setMetadata
-
idpLinks
-
addIdpLinksItem
-
getIdpLinks
Get idpLinks- Returns:
- idpLinks
-
setIdpLinks
-
totpSecret
-
getTotpSecret
An Implementation of RFC 6238 is used, with HMAC-SHA-1 and time-step of 30 seconds. Currently no other options are supported, and if anything different is used the validation will fail.- Returns:
- totpSecret
-
getTotpSecret_JsonNullable
-
setTotpSecret_JsonNullable
public void setTotpSecret_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> totpSecret) -
setTotpSecret
-
hashedPassword
public UserServiceAddHumanUserRequest hashedPassword(@Nullable UserServiceHashedPassword hashedPassword) -
getHashedPassword
Get hashedPassword- Returns:
- hashedPassword
-
setHashedPassword
-
password
-
getPassword
Get password- Returns:
- password
-
setPassword
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-