Class UserServiceCreateUserRequest

java.lang.Object
com.zitadel.model.UserServiceCreateUserRequest

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class UserServiceCreateUserRequest extends Object
UserServiceCreateUserRequest
  • Field Details

  • Constructor Details

    • UserServiceCreateUserRequest

      public UserServiceCreateUserRequest()
  • Method Details

    • organizationId

      public UserServiceCreateUserRequest organizationId(@Nullable String organizationId)
    • getOrganizationId

      @Nullable public String getOrganizationId()
      The unique identifier of the organization the user belongs to.
      Returns:
      organizationId
    • setOrganizationId

      public void setOrganizationId(@Nullable String organizationId)
    • userId

    • getUserId

      @Nullable public String getUserId()
      The ID is a unique identifier for the user in the instance. If not specified, it will be generated. You can set your own user id that is unique within the instance. This is useful in migration scenarios, for example if the user already has an ID in another Zitadel system. If not specified, it will be generated. It can't be changed after creation.
      Returns:
      userId
    • getUserId_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getUserId_JsonNullable()
    • setUserId_JsonNullable

      public void setUserId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> userId)
    • setUserId

      public void setUserId(@Nullable String userId)
    • username

      public UserServiceCreateUserRequest username(@Nullable String username)
    • getUsername

      @Nullable public String getUsername()
      The username is a unique identifier for the user in the organization. If not specified, Zitadel sets the username to the email for users of type human and to the user_id for users of type machine. It is used to identify the user in the organization and can be used for login.
      Returns:
      username
    • getUsername_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getUsername_JsonNullable()
    • setUsername_JsonNullable

      public void setUsername_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> username)
    • setUsername

      public void setUsername(@Nullable String username)
    • human

    • getHuman

      @Nullable public UserServiceHuman getHuman()
      Get human
      Returns:
      human
    • setHuman

      public void setHuman(@Nullable UserServiceHuman human)
    • machine

    • getMachine

      @Nullable public UserServiceMachine getMachine()
      Get machine
      Returns:
      machine
    • setMachine

      public void setMachine(@Nullable UserServiceMachine machine)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string