Package com.zitadel.model
Class UserServiceDomainQuery
java.lang.Object
com.zitadel.model.UserServiceDomainQuery
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class UserServiceDomainQuery
extends Object
UserServiceDomainQuery
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanList only auth methods with specific domain.List also auth method types without domain information like passkey and U2F added through V1 APIs / Login UI.inthashCode()includeWithoutDomain(Boolean includeWithoutDomain) voidvoidsetIncludeWithoutDomain(Boolean includeWithoutDomain) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_INCLUDE_WITHOUT_DOMAIN
- See Also:
-
JSON_PROPERTY_DOMAIN
- See Also:
-
-
Constructor Details
-
UserServiceDomainQuery
public UserServiceDomainQuery()
-
-
Method Details
-
includeWithoutDomain
-
getIncludeWithoutDomain
List also auth method types without domain information like passkey and U2F added through V1 APIs / Login UI.- Returns:
- includeWithoutDomain
-
setIncludeWithoutDomain
-
domain
-
getDomain
List only auth methods with specific domain.- Returns:
- domain
-
setDomain
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-