Class UserServiceSendInviteCode

java.lang.Object
com.zitadel.model.UserServiceSendInviteCode

@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen", comments="Generator version: 7.14.0") public class UserServiceSendInviteCode extends Object
UserServiceSendInviteCode
  • Field Details

  • Constructor Details

    • UserServiceSendInviteCode

      public UserServiceSendInviteCode()
  • Method Details

    • urlTemplate

      public UserServiceSendInviteCode urlTemplate(@Nullable String urlTemplate)
    • getUrlTemplate

      @Nullable public String getUrlTemplate()
      Optionally set a url_template, which will be used in the invite mail sent by ZITADEL to guide the user to your invitation page. If no template is set and no previous code was created, the default ZITADEL url will be used. The following placeholders can be used: UserID, OrgID, Code
      Returns:
      urlTemplate
    • getUrlTemplate_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getUrlTemplate_JsonNullable()
    • setUrlTemplate_JsonNullable

      public void setUrlTemplate_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> urlTemplate)
    • setUrlTemplate

      public void setUrlTemplate(@Nullable String urlTemplate)
    • applicationName

      public UserServiceSendInviteCode applicationName(@Nullable String applicationName)
    • getApplicationName

      @Nullable public String getApplicationName()
      Optionally set an application name, which will be used in the invite mail sent by ZITADEL. If no application name is set and no previous code was created, ZITADEL will be used as default.
      Returns:
      applicationName
    • getApplicationName_JsonNullable

      public org.openapitools.jackson.nullable.JsonNullable<String> getApplicationName_JsonNullable()
    • setApplicationName_JsonNullable

      public void setApplicationName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> applicationName)
    • setApplicationName

      public void setApplicationName(@Nullable String applicationName)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • toUrlQueryString

      public String toUrlQueryString()
      Convert the instance into URL query string.
      Returns:
      URL query string
    • toUrlQueryString

      public String toUrlQueryString(String prefix)
      Convert the instance into URL query string.
      Parameters:
      prefix - prefix of the query string
      Returns:
      URL query string