Package com.zitadel.model
Class UserServiceUpdateUserRequest
java.lang.Object
com.zitadel.model.UserServiceUpdateUserRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class UserServiceUpdateUserRequest
extends Object
UserServiceUpdateUserRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleangetHuman()Get humanGet machineThe user id is the users unique identifier in the instance.Set a new username that is unique within the instance.org.openapitools.jackson.nullable.JsonNullable<String>inthashCode()human(UserServiceHuman human) machine(UserServiceMachine machine) voidsetHuman(UserServiceHuman human) voidsetMachine(UserServiceMachine machine) voidvoidsetUsername(String username) voidsetUsername_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> username) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_USER_ID
- See Also:
-
JSON_PROPERTY_USERNAME
- See Also:
-
JSON_PROPERTY_HUMAN
- See Also:
-
JSON_PROPERTY_MACHINE
- See Also:
-
-
Constructor Details
-
UserServiceUpdateUserRequest
public UserServiceUpdateUserRequest()
-
-
Method Details
-
userId
-
getUserId
The user id is the users unique identifier in the instance. It can't be changed.- Returns:
- userId
-
setUserId
-
username
-
getUsername
Set a new username that is unique within the instance. Beware that active tokens and sessions are invalidated when the username is changed.- Returns:
- username
-
getUsername_JsonNullable
-
setUsername_JsonNullable
public void setUsername_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> username) -
setUsername
-
human
-
getHuman
Get human- Returns:
- human
-
setHuman
-
machine
-
getMachine
Get machine- Returns:
- machine
-
setMachine
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-