Package com.zitadel.model
Class WebKeyServiceConnectError
- All Implemented Interfaces:
Serializable,Cloneable,Map<String,Object>
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class WebKeyServiceConnectError
extends HashMap<String,Object>
Error type returned by Connect: https://connectrpc.com/docs/go/errors/#http-representation
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic enumThe status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].Nested classes/interfaces inherited from class java.util.AbstractMap
AbstractMap.SimpleEntry<K extends Object,V extends Object>, AbstractMap.SimpleImmutableEntry<K extends Object, V extends Object> -
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddDetailsItem(WebKeyServiceAny detailsItem) details(List<WebKeyServiceAny> details) booleangetCode()The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].A list of messages that carry the error details.A developer-facing error message, which should be in English.inthashCode()voidvoidsetDetails(List<WebKeyServiceAny> details) voidsetMessage(String message) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.Methods inherited from class java.util.HashMap
clear, clone, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, forEach, get, getOrDefault, isEmpty, keySet, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, values
-
Field Details
-
JSON_PROPERTY_CODE
- See Also:
-
JSON_PROPERTY_MESSAGE
- See Also:
-
JSON_PROPERTY_DETAILS
- See Also:
-
-
Constructor Details
-
WebKeyServiceConnectError
public WebKeyServiceConnectError()
-
-
Method Details
-
code
-
getCode
The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].- Returns:
- code
-
setCode
-
message
-
getMessage
A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the [google.rpc.Status.details][google.rpc.Status.details] field, or localized by the client.- Returns:
- message
-
setMessage
-
details
-
addDetailsItem
-
getDetails
A list of messages that carry the error details. There is no limit on the number of messages.- Returns:
- details
-
setDetails
-
equals
-
hashCode
public int hashCode() -
toString
- Overrides:
toStringin classAbstractMap<String,Object>
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-