Uses of Enum
com.zitadel.model.ApplicationServiceConnectError.CodeEnum
Packages that use ApplicationServiceConnectError.CodeEnum
-
Uses of ApplicationServiceConnectError.CodeEnum in com.zitadel.model
Methods in com.zitadel.model that return ApplicationServiceConnectError.CodeEnumModifier and TypeMethodDescriptionApplicationServiceConnectError.getCode()The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].Returns the enum constant of this type with the specified name.ApplicationServiceConnectError.CodeEnum.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type ApplicationServiceConnectError.CodeEnumModifier and TypeMethodDescriptionApplicationServiceConnectError.code(ApplicationServiceConnectError.CodeEnum code) voidApplicationServiceConnectError.setCode(ApplicationServiceConnectError.CodeEnum code)