Uses of Enum
com.zitadel.model.BetaInstanceServiceTextQueryMethod
Packages that use BetaInstanceServiceTextQueryMethod
-
Uses of BetaInstanceServiceTextQueryMethod in com.zitadel.model
Methods in com.zitadel.model that return BetaInstanceServiceTextQueryMethodModifier and TypeMethodDescriptionBetaInstanceServiceDomainQuery.getMethod()Get methodReturns the enum constant of this type with the specified name.static BetaInstanceServiceTextQueryMethod[]BetaInstanceServiceTextQueryMethod.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type BetaInstanceServiceTextQueryMethodModifier and TypeMethodDescriptionBetaInstanceServiceDomainQuery.method(BetaInstanceServiceTextQueryMethod method) voidBetaInstanceServiceDomainQuery.setMethod(BetaInstanceServiceTextQueryMethod method)