Uses of Enum
com.zitadel.model.BetaProjectServiceConnectError.CodeEnum
Packages that use BetaProjectServiceConnectError.CodeEnum
-
Uses of BetaProjectServiceConnectError.CodeEnum in com.zitadel.model
Methods in com.zitadel.model that return BetaProjectServiceConnectError.CodeEnumModifier and TypeMethodDescriptionBetaProjectServiceConnectError.getCode()The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].Returns the enum constant of this type with the specified name.BetaProjectServiceConnectError.CodeEnum.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type BetaProjectServiceConnectError.CodeEnumModifier and TypeMethodDescriptionBetaProjectServiceConnectError.code(BetaProjectServiceConnectError.CodeEnum code) voidBetaProjectServiceConnectError.setCode(BetaProjectServiceConnectError.CodeEnum code)