Uses of Enum
com.zitadel.model.BetaSessionServiceTimestampQueryMethod
Packages that use BetaSessionServiceTimestampQueryMethod
-
Uses of BetaSessionServiceTimestampQueryMethod in com.zitadel.model
Methods in com.zitadel.model that return BetaSessionServiceTimestampQueryMethodModifier and TypeMethodDescriptionBetaSessionServiceCreationDateQuery.getMethod()Get methodReturns the enum constant of this type with the specified name.BetaSessionServiceTimestampQueryMethod.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type BetaSessionServiceTimestampQueryMethodModifier and TypeMethodDescriptionBetaSessionServiceCreationDateQuery.method(BetaSessionServiceTimestampQueryMethod method) voidBetaSessionServiceCreationDateQuery.setMethod(BetaSessionServiceTimestampQueryMethod method)