Uses of Enum
com.zitadel.model.BetaTelemetryServiceConnectError.CodeEnum
Packages that use BetaTelemetryServiceConnectError.CodeEnum
-
Uses of BetaTelemetryServiceConnectError.CodeEnum in com.zitadel.model
Methods in com.zitadel.model that return BetaTelemetryServiceConnectError.CodeEnumModifier and TypeMethodDescriptionBetaTelemetryServiceConnectError.getCode()The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].Returns the enum constant of this type with the specified name.BetaTelemetryServiceConnectError.CodeEnum.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type BetaTelemetryServiceConnectError.CodeEnumModifier and TypeMethodDescriptionBetaTelemetryServiceConnectError.code(BetaTelemetryServiceConnectError.CodeEnum code) voidBetaTelemetryServiceConnectError.setCode(BetaTelemetryServiceConnectError.CodeEnum code)