Uses of Enum
com.zitadel.model.BetaWebKeyServiceConnectError.CodeEnum
Packages that use BetaWebKeyServiceConnectError.CodeEnum
-
Uses of BetaWebKeyServiceConnectError.CodeEnum in com.zitadel.model
Methods in com.zitadel.model that return BetaWebKeyServiceConnectError.CodeEnumModifier and TypeMethodDescriptionBetaWebKeyServiceConnectError.getCode()The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].Returns the enum constant of this type with the specified name.BetaWebKeyServiceConnectError.CodeEnum.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type BetaWebKeyServiceConnectError.CodeEnumModifier and TypeMethodDescriptionBetaWebKeyServiceConnectError.code(BetaWebKeyServiceConnectError.CodeEnum code) voidBetaWebKeyServiceConnectError.setCode(BetaWebKeyServiceConnectError.CodeEnum code)