Uses of Enum
com.zitadel.model.FeatureServiceConnectError.CodeEnum
Packages that use FeatureServiceConnectError.CodeEnum
-
Uses of FeatureServiceConnectError.CodeEnum in com.zitadel.model
Methods in com.zitadel.model that return FeatureServiceConnectError.CodeEnumModifier and TypeMethodDescriptionFeatureServiceConnectError.getCode()The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].Returns the enum constant of this type with the specified name.static FeatureServiceConnectError.CodeEnum[]FeatureServiceConnectError.CodeEnum.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type FeatureServiceConnectError.CodeEnumModifier and TypeMethodDescriptionFeatureServiceConnectError.code(FeatureServiceConnectError.CodeEnum code) voidFeatureServiceConnectError.setCode(FeatureServiceConnectError.CodeEnum code)