Uses of Enum
com.zitadel.model.IdentityProviderServiceSAMLSignatureAlgorithm
Packages that use IdentityProviderServiceSAMLSignatureAlgorithm
-
Uses of IdentityProviderServiceSAMLSignatureAlgorithm in com.zitadel.model
Methods in com.zitadel.model that return IdentityProviderServiceSAMLSignatureAlgorithmModifier and TypeMethodDescriptionIdentityProviderServiceSAMLConfig.getSignatureAlgorithm()Get signatureAlgorithmReturns the enum constant of this type with the specified name.IdentityProviderServiceSAMLSignatureAlgorithm.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type IdentityProviderServiceSAMLSignatureAlgorithmModifier and TypeMethodDescriptionvoidIdentityProviderServiceSAMLConfig.setSignatureAlgorithm(IdentityProviderServiceSAMLSignatureAlgorithm signatureAlgorithm) IdentityProviderServiceSAMLConfig.signatureAlgorithm(IdentityProviderServiceSAMLSignatureAlgorithm signatureAlgorithm)