Uses of Enum
com.zitadel.model.InstanceServiceConnectError.CodeEnum
Packages that use InstanceServiceConnectError.CodeEnum
-
Uses of InstanceServiceConnectError.CodeEnum in com.zitadel.model
Methods in com.zitadel.model that return InstanceServiceConnectError.CodeEnumModifier and TypeMethodDescriptionInstanceServiceConnectError.getCode()The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].Returns the enum constant of this type with the specified name.static InstanceServiceConnectError.CodeEnum[]InstanceServiceConnectError.CodeEnum.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type InstanceServiceConnectError.CodeEnumModifier and TypeMethodDescriptionInstanceServiceConnectError.code(InstanceServiceConnectError.CodeEnum code) voidInstanceServiceConnectError.setCode(InstanceServiceConnectError.CodeEnum code)