Uses of Enum
com.zitadel.model.InstanceServiceTextQueryMethod
Packages that use InstanceServiceTextQueryMethod
-
Uses of InstanceServiceTextQueryMethod in com.zitadel.model
Methods in com.zitadel.model that return InstanceServiceTextQueryMethodModifier and TypeMethodDescriptionInstanceServiceDomainFilter.getMethod()Get methodReturns the enum constant of this type with the specified name.static InstanceServiceTextQueryMethod[]InstanceServiceTextQueryMethod.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type InstanceServiceTextQueryMethodModifier and TypeMethodDescriptionInstanceServiceDomainFilter.method(InstanceServiceTextQueryMethod method) voidInstanceServiceDomainFilter.setMethod(InstanceServiceTextQueryMethod method)