Uses of Enum
com.zitadel.model.OrganizationServiceTextQueryMethod
Packages that use OrganizationServiceTextQueryMethod
-
Uses of OrganizationServiceTextQueryMethod in com.zitadel.model
Methods in com.zitadel.model that return OrganizationServiceTextQueryMethodModifier and TypeMethodDescriptionOrganizationServiceOrganizationDomainQuery.getMethod()Get methodOrganizationServiceOrganizationNameQuery.getMethod()Get methodReturns the enum constant of this type with the specified name.static OrganizationServiceTextQueryMethod[]OrganizationServiceTextQueryMethod.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type OrganizationServiceTextQueryMethodModifier and TypeMethodDescriptionOrganizationServiceOrganizationDomainQuery.method(OrganizationServiceTextQueryMethod method) OrganizationServiceOrganizationNameQuery.method(OrganizationServiceTextQueryMethod method) voidOrganizationServiceOrganizationDomainQuery.setMethod(OrganizationServiceTextQueryMethod method) voidOrganizationServiceOrganizationNameQuery.setMethod(OrganizationServiceTextQueryMethod method)