Uses of Enum
com.zitadel.model.ProjectServiceConnectError.CodeEnum
Packages that use ProjectServiceConnectError.CodeEnum
-
Uses of ProjectServiceConnectError.CodeEnum in com.zitadel.model
Methods in com.zitadel.model that return ProjectServiceConnectError.CodeEnumModifier and TypeMethodDescriptionProjectServiceConnectError.getCode()The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].Returns the enum constant of this type with the specified name.static ProjectServiceConnectError.CodeEnum[]ProjectServiceConnectError.CodeEnum.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type ProjectServiceConnectError.CodeEnumModifier and TypeMethodDescriptionProjectServiceConnectError.code(ProjectServiceConnectError.CodeEnum code) voidProjectServiceConnectError.setCode(ProjectServiceConnectError.CodeEnum code)