Uses of Enum
com.zitadel.model.ProjectServiceProjectState
Packages that use ProjectServiceProjectState
-
Uses of ProjectServiceProjectState in com.zitadel.model
Methods in com.zitadel.model that return ProjectServiceProjectStateModifier and TypeMethodDescriptionstatic ProjectServiceProjectStateProjectServiceProject.getState()Get statestatic ProjectServiceProjectStateReturns the enum constant of this type with the specified name.static ProjectServiceProjectState[]ProjectServiceProjectState.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type ProjectServiceProjectStateModifier and TypeMethodDescriptionvoidProjectServiceProject.setState(ProjectServiceProjectState state) ProjectServiceProject.state(ProjectServiceProjectState state)