Uses of Enum
com.zitadel.model.SessionServiceConnectError.CodeEnum
Packages that use SessionServiceConnectError.CodeEnum
-
Uses of SessionServiceConnectError.CodeEnum in com.zitadel.model
Methods in com.zitadel.model that return SessionServiceConnectError.CodeEnumModifier and TypeMethodDescriptionSessionServiceConnectError.getCode()The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].Returns the enum constant of this type with the specified name.static SessionServiceConnectError.CodeEnum[]SessionServiceConnectError.CodeEnum.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type SessionServiceConnectError.CodeEnumModifier and TypeMethodDescriptionSessionServiceConnectError.code(SessionServiceConnectError.CodeEnum code) voidSessionServiceConnectError.setCode(SessionServiceConnectError.CodeEnum code)