Uses of Enum
com.zitadel.model.SessionServiceTimestampQueryMethod
Packages that use SessionServiceTimestampQueryMethod
-
Uses of SessionServiceTimestampQueryMethod in com.zitadel.model
Methods in com.zitadel.model that return SessionServiceTimestampQueryMethodModifier and TypeMethodDescriptionSessionServiceCreationDateQuery.getMethod()Get methodSessionServiceExpirationDateQuery.getMethod()Get methodReturns the enum constant of this type with the specified name.static SessionServiceTimestampQueryMethod[]SessionServiceTimestampQueryMethod.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type SessionServiceTimestampQueryMethodModifier and TypeMethodDescriptionSessionServiceCreationDateQuery.method(SessionServiceTimestampQueryMethod method) SessionServiceExpirationDateQuery.method(SessionServiceTimestampQueryMethod method) voidSessionServiceCreationDateQuery.setMethod(SessionServiceTimestampQueryMethod method) voidSessionServiceExpirationDateQuery.setMethod(SessionServiceTimestampQueryMethod method)