Uses of Class
com.zitadel.model.UserServiceAddKeyRequest
Packages that use UserServiceAddKeyRequest
-
Uses of UserServiceAddKeyRequest in com.zitadel.api
Methods in com.zitadel.api with parameters of type UserServiceAddKeyRequestModifier and TypeMethodDescriptionUserServiceApi.addKey(UserServiceAddKeyRequest userServiceAddKeyRequest) Add a Key Add a keys that can be used to securely authenticate at the Zitadel APIs using JWT profile authentication using short-lived tokens. -
Uses of UserServiceAddKeyRequest in com.zitadel.model
Methods in com.zitadel.model that return UserServiceAddKeyRequestModifier and TypeMethodDescriptionUserServiceAddKeyRequest.expirationDate(OffsetDateTime expirationDate) UserServiceAddKeyRequest.publicKey(byte[] publicKey)