Uses of Enum
com.zitadel.model.UserServiceConnectError.CodeEnum
Packages that use UserServiceConnectError.CodeEnum
-
Uses of UserServiceConnectError.CodeEnum in com.zitadel.model
Methods in com.zitadel.model that return UserServiceConnectError.CodeEnumModifier and TypeMethodDescriptionUserServiceConnectError.getCode()The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].Returns the enum constant of this type with the specified name.static UserServiceConnectError.CodeEnum[]UserServiceConnectError.CodeEnum.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type UserServiceConnectError.CodeEnumModifier and TypeMethodDescriptionUserServiceConnectError.code(UserServiceConnectError.CodeEnum code) voidUserServiceConnectError.setCode(UserServiceConnectError.CodeEnum code)