Uses of Class
com.zitadel.model.UserServiceCreateInviteCodeResponse
Packages that use UserServiceCreateInviteCodeResponse
-
Uses of UserServiceCreateInviteCodeResponse in com.zitadel.api
Methods in com.zitadel.api that return UserServiceCreateInviteCodeResponseModifier and TypeMethodDescriptionUserServiceApi.createInviteCode()Create an invite code for a user (Convenience Method) Create an invite code for a user to initialize their first authentication method (password, passkeys, IdP) depending on the organization's available methods.UserServiceApi.createInviteCode(UserServiceCreateInviteCodeRequest userServiceCreateInviteCodeRequest) Create an invite code for a user Create an invite code for a user to initialize their first authentication method (password, passkeys, IdP) depending on the organization's available methods. -
Uses of UserServiceCreateInviteCodeResponse in com.zitadel.model
Methods in com.zitadel.model that return UserServiceCreateInviteCodeResponseModifier and TypeMethodDescriptionUserServiceCreateInviteCodeResponse.details(UserServiceDetails details) UserServiceCreateInviteCodeResponse.inviteCode(String inviteCode)