Uses of Enum
com.zitadel.model.WebKeyServiceConnectError.CodeEnum
Packages that use WebKeyServiceConnectError.CodeEnum
-
Uses of WebKeyServiceConnectError.CodeEnum in com.zitadel.model
Methods in com.zitadel.model that return WebKeyServiceConnectError.CodeEnumModifier and TypeMethodDescriptionWebKeyServiceConnectError.getCode()The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].Returns the enum constant of this type with the specified name.static WebKeyServiceConnectError.CodeEnum[]WebKeyServiceConnectError.CodeEnum.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.zitadel.model with parameters of type WebKeyServiceConnectError.CodeEnumModifier and TypeMethodDescriptionWebKeyServiceConnectError.code(WebKeyServiceConnectError.CodeEnum code) voidWebKeyServiceConnectError.setCode(WebKeyServiceConnectError.CodeEnum code)