Class StringUtil

java.lang.Object
com.zitadel.utils.StringUtil

public class StringUtil extends Object
  • Method Details

    • join

      public static String join(String[] array, String separator)
      Join an array of strings with the given separator.

      Note: This might be replaced by utility method from commons-lang or guava someday if one of those libraries is added as dependency.

      Parameters:
      array - The array of strings
      separator - The separator
      Returns:
      the resulting string