Package com.zitadel.api
Class ProjectServiceApi
java.lang.Object
com.zitadel.BaseApi
com.zitadel.api.ProjectServiceApi
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ProjectServiceApi
extends BaseApi
-
Field Summary
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionactivateProject(ProjectServiceActivateProjectRequest projectServiceActivateProjectRequest) Activate Project Set the state of a project to active.activateProjectGrant(ProjectServiceActivateProjectGrantRequest projectServiceActivateProjectGrantRequest) Activate Project Grant Set the state of the project grant to activated.addProjectRole(ProjectServiceAddProjectRoleRequest projectServiceAddProjectRoleRequest) Add Project Role Add a new project role to a project.createProject(ProjectServiceCreateProjectRequest projectServiceCreateProjectRequest) Create Project Create a new project.createProjectGrant(ProjectServiceCreateProjectGrantRequest projectServiceCreateProjectGrantRequest) Create Project Grant Grant a project to another organization.deactivateProject(ProjectServiceDeactivateProjectRequest projectServiceDeactivateProjectRequest) Deactivate Project Set the state of a project to deactivated.deactivateProjectGrant(ProjectServiceDeactivateProjectGrantRequest projectServiceDeactivateProjectGrantRequest) Deactivate Project Grant Set the state of the project grant to deactivated.deleteProject(ProjectServiceDeleteProjectRequest projectServiceDeleteProjectRequest) Delete Project Delete an existing project.deleteProjectGrant(ProjectServiceDeleteProjectGrantRequest projectServiceDeleteProjectGrantRequest) Delete Project Grant Delete a project grant.getProject(ProjectServiceGetProjectRequest projectServiceGetProjectRequest) Get Project Returns the project identified by the requested ID.<T> TinvokeAPI(String url, String method, Object request, com.fasterxml.jackson.core.type.TypeReference<T> returnType, Map<String, String> additionalHeaders) Directly invoke the API for the given URL.listProjectGrants(ProjectServiceListProjectGrantsRequest projectServiceListProjectGrantsRequest) List Project Grants Returns a list of project grants.listProjectRoles(ProjectServiceListProjectRolesRequest projectServiceListProjectRolesRequest) List Project Roles Returns all roles of a project matching the search query.listProjects(ProjectServiceListProjectsRequest projectServiceListProjectsRequest) List Projects List all matching projects.removeProjectRole(ProjectServiceRemoveProjectRoleRequest projectServiceRemoveProjectRoleRequest) Remove Project Role Removes the role from the project and on every resource it has a dependency.updateProject(ProjectServiceUpdateProjectRequest projectServiceUpdateProjectRequest) Update Project Update an existing project.updateProjectGrant(ProjectServiceUpdateProjectGrantRequest projectServiceUpdateProjectGrantRequest) Update Project Grant Change the roles of the project that is granted to another organization.updateProjectRole(ProjectServiceUpdateProjectRoleRequest projectServiceUpdateProjectRoleRequest) Update Project Role Change a project role.
-
Constructor Details
-
ProjectServiceApi
public ProjectServiceApi() -
ProjectServiceApi
-
-
Method Details
-
activateProject
public ProjectServiceActivateProjectResponse activateProject(ProjectServiceActivateProjectRequest projectServiceActivateProjectRequest) throws ApiException Activate Project Set the state of a project to active. Request returns no error if the project is already activated. Required permission: - `project.write`- Parameters:
projectServiceActivateProjectRequest- (required)- Returns:
- ProjectServiceActivateProjectResponse
- Throws:
ApiException- if fails to make API call
-
activateProjectGrant
public ProjectServiceActivateProjectGrantResponse activateProjectGrant(ProjectServiceActivateProjectGrantRequest projectServiceActivateProjectGrantRequest) throws ApiException Activate Project Grant Set the state of the project grant to activated. Required permission: - `project.grant.write`- Parameters:
projectServiceActivateProjectGrantRequest- (required)- Returns:
- ProjectServiceActivateProjectGrantResponse
- Throws:
ApiException- if fails to make API call
-
addProjectRole
public ProjectServiceAddProjectRoleResponse addProjectRole(ProjectServiceAddProjectRoleRequest projectServiceAddProjectRoleRequest) throws ApiException Add Project Role Add a new project role to a project. The key must be unique within the project. Required permission: - `project.role.write`- Parameters:
projectServiceAddProjectRoleRequest- (required)- Returns:
- ProjectServiceAddProjectRoleResponse
- Throws:
ApiException- if fails to make API call
-
createProject
public ProjectServiceCreateProjectResponse createProject(ProjectServiceCreateProjectRequest projectServiceCreateProjectRequest) throws ApiException Create Project Create a new project. A project is a vessel to group applications, roles and authorizations. Every project belongs to exactly one organization, but can be granted to other organizations for self-management of their authorizations. Required permission: - `project.create`- Parameters:
projectServiceCreateProjectRequest- (required)- Returns:
- ProjectServiceCreateProjectResponse
- Throws:
ApiException- if fails to make API call
-
createProjectGrant
public ProjectServiceCreateProjectGrantResponse createProjectGrant(ProjectServiceCreateProjectGrantRequest projectServiceCreateProjectGrantRequest) throws ApiException Create Project Grant Grant a project to another organization. The project grant will allow the granted organization to access the project and manage the authorizations for its users. Required permission: - `project.grant.create`- Parameters:
projectServiceCreateProjectGrantRequest- (required)- Returns:
- ProjectServiceCreateProjectGrantResponse
- Throws:
ApiException- if fails to make API call
-
deactivateProject
public ProjectServiceDeactivateProjectResponse deactivateProject(ProjectServiceDeactivateProjectRequest projectServiceDeactivateProjectRequest) throws ApiException Deactivate Project Set the state of a project to deactivated. Request returns no error if the project is already deactivated. Applications under deactivated projects are not able to login anymore. Required permission: - `project.write`- Parameters:
projectServiceDeactivateProjectRequest- (required)- Returns:
- ProjectServiceDeactivateProjectResponse
- Throws:
ApiException- if fails to make API call
-
deactivateProjectGrant
public ProjectServiceDeactivateProjectGrantResponse deactivateProjectGrant(ProjectServiceDeactivateProjectGrantRequest projectServiceDeactivateProjectGrantRequest) throws ApiException Deactivate Project Grant Set the state of the project grant to deactivated. Applications under deactivated projects grants are not able to login anymore. Required permission: - `project.grant.write`- Parameters:
projectServiceDeactivateProjectGrantRequest- (required)- Returns:
- ProjectServiceDeactivateProjectGrantResponse
- Throws:
ApiException- if fails to make API call
-
deleteProject
public ProjectServiceDeleteProjectResponse deleteProject(ProjectServiceDeleteProjectRequest projectServiceDeleteProjectRequest) throws ApiException Delete Project Delete an existing project. In case the project is not found, the request will return a successful response as the desired state is already achieved. Required permission: - `project.delete`- Parameters:
projectServiceDeleteProjectRequest- (required)- Returns:
- ProjectServiceDeleteProjectResponse
- Throws:
ApiException- if fails to make API call
-
deleteProjectGrant
public ProjectServiceDeleteProjectGrantResponse deleteProjectGrant(ProjectServiceDeleteProjectGrantRequest projectServiceDeleteProjectGrantRequest) throws ApiException Delete Project Grant Delete a project grant. All user grants for this project grant will also be removed. A user will not have access to the project afterward (if permissions are checked). In case the project grant is not found, the request will return a successful response as the desired state is already achieved. Required permission: - `project.grant.delete`- Parameters:
projectServiceDeleteProjectGrantRequest- (required)- Returns:
- ProjectServiceDeleteProjectGrantResponse
- Throws:
ApiException- if fails to make API call
-
getProject
public ProjectServiceGetProjectResponse getProject(ProjectServiceGetProjectRequest projectServiceGetProjectRequest) throws ApiException Get Project Returns the project identified by the requested ID. Required permission: - `project.read`- Parameters:
projectServiceGetProjectRequest- (required)- Returns:
- ProjectServiceGetProjectResponse
- Throws:
ApiException- if fails to make API call
-
listProjectGrants
public ProjectServiceListProjectGrantsResponse listProjectGrants(ProjectServiceListProjectGrantsRequest projectServiceListProjectGrantsRequest) throws ApiException List Project Grants Returns a list of project grants. A project grant is when the organization grants its project to another organization. Required permission: - `project.grant.read`- Parameters:
projectServiceListProjectGrantsRequest- (required)- Returns:
- ProjectServiceListProjectGrantsResponse
- Throws:
ApiException- if fails to make API call
-
listProjectRoles
public ProjectServiceListProjectRolesResponse listProjectRoles(ProjectServiceListProjectRolesRequest projectServiceListProjectRolesRequest) throws ApiException List Project Roles Returns all roles of a project matching the search query. Required permission: - `project.role.read`- Parameters:
projectServiceListProjectRolesRequest- (required)- Returns:
- ProjectServiceListProjectRolesResponse
- Throws:
ApiException- if fails to make API call
-
listProjects
public ProjectServiceListProjectsResponse listProjects(ProjectServiceListProjectsRequest projectServiceListProjectsRequest) throws ApiException List Projects List all matching projects. By default all projects of the instance that the caller has permission to read are returned. Make sure to include a limit and sorting for pagination. Required permission: - `project.read`- Parameters:
projectServiceListProjectsRequest- (required)- Returns:
- ProjectServiceListProjectsResponse
- Throws:
ApiException- if fails to make API call
-
removeProjectRole
public ProjectServiceRemoveProjectRoleResponse removeProjectRole(ProjectServiceRemoveProjectRoleRequest projectServiceRemoveProjectRoleRequest) throws ApiException Remove Project Role Removes the role from the project and on every resource it has a dependency. This includes project grants and user grants. Required permission: - `project.role.write`- Parameters:
projectServiceRemoveProjectRoleRequest- (required)- Returns:
- ProjectServiceRemoveProjectRoleResponse
- Throws:
ApiException- if fails to make API call
-
updateProject
public ProjectServiceUpdateProjectResponse updateProject(ProjectServiceUpdateProjectRequest projectServiceUpdateProjectRequest) throws ApiException Update Project Update an existing project. Required permission: - `project.write`- Parameters:
projectServiceUpdateProjectRequest- (required)- Returns:
- ProjectServiceUpdateProjectResponse
- Throws:
ApiException- if fails to make API call
-
updateProjectGrant
public ProjectServiceUpdateProjectGrantResponse updateProjectGrant(ProjectServiceUpdateProjectGrantRequest projectServiceUpdateProjectGrantRequest) throws ApiException Update Project Grant Change the roles of the project that is granted to another organization. The project grant will allow the granted organization to access the project and manage the authorizations for its users. Required permission: - `project.grant.write`- Parameters:
projectServiceUpdateProjectGrantRequest- (required)- Returns:
- ProjectServiceUpdateProjectGrantResponse
- Throws:
ApiException- if fails to make API call
-
updateProjectRole
public ProjectServiceUpdateProjectRoleResponse updateProjectRole(ProjectServiceUpdateProjectRoleRequest projectServiceUpdateProjectRoleRequest) throws ApiException Update Project Role Change a project role. The key is not editable. If a key should change, remove the role and create a new one. Required permission: - `project.role.write`- Parameters:
projectServiceUpdateProjectRoleRequest- (required)- Returns:
- ProjectServiceUpdateProjectRoleResponse
- Throws:
ApiException- if fails to make API call
-
invokeAPI
public <T> T invokeAPI(String url, String method, Object request, com.fasterxml.jackson.core.type.TypeReference<T> returnType, Map<String, String> additionalHeaders) throws ApiExceptionDescription copied from class:BaseApiDirectly invoke the API for the given URL. Useful if the API returns direct links/URLs for subsequent requests.- Specified by:
invokeAPIin classBaseApi- Parameters:
url- The URL for the request, either full URL or only the path.method- The HTTP method for the request.request- The request object.returnType- The return type.additionalHeaders- Additional headers for the request.- Returns:
- The API response in the specified type.
- Throws:
ApiException- if fails to make API call.
-