Package com.zitadel.model
Class ActionServiceUpdateTargetRequest
java.lang.Object
com.zitadel.model.ActionServiceUpdateTargetRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ActionServiceUpdateTargetRequest
extends Object
ActionServiceUpdateTargetRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanexpirationSigningKey(String expirationSigningKey) The new URL of the endpoint to call.org.openapitools.jackson.nullable.JsonNullable<String>A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.getId()The unique identifier of the target to update.getName()Optionally, update the name of the target.org.openapitools.jackson.nullable.JsonNullable<String>Get payloadTypeGet restAsyncGet restCallGet restWebhookA Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.inthashCode()payloadType(ActionServicePayloadType payloadType) restCall(ActionServiceRESTCall restCall) restWebhook(ActionServiceRESTWebhook restWebhook) voidsetEndpoint(String endpoint) voidsetEndpoint_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> endpoint) voidsetExpirationSigningKey(String expirationSigningKey) voidvoidvoidsetName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> name) voidsetPayloadType(ActionServicePayloadType payloadType) voidsetRestAsync(Object restAsync) voidsetRestCall(ActionServiceRESTCall restCall) voidsetRestWebhook(ActionServiceRESTWebhook restWebhook) voidsetTimeout(String timeout) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_ID
- See Also:
-
JSON_PROPERTY_NAME
- See Also:
-
JSON_PROPERTY_TIMEOUT
- See Also:
-
JSON_PROPERTY_ENDPOINT
- See Also:
-
JSON_PROPERTY_EXPIRATION_SIGNING_KEY
- See Also:
-
JSON_PROPERTY_PAYLOAD_TYPE
- See Also:
-
JSON_PROPERTY_REST_ASYNC
- See Also:
-
JSON_PROPERTY_REST_CALL
- See Also:
-
JSON_PROPERTY_REST_WEBHOOK
- See Also:
-
-
Constructor Details
-
ActionServiceUpdateTargetRequest
public ActionServiceUpdateTargetRequest()
-
-
Method Details
-
id
-
getId
The unique identifier of the target to update.- Returns:
- id
-
setId
-
name
-
getName
Optionally, update the name of the target. If not set, the name will not be changed.- Returns:
- name
-
getName_JsonNullable
-
setName_JsonNullable
-
setName
-
timeout
-
getTimeout
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like \"day\" or \"month\". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +-10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = ...; Timestamp end = ...; Duration duration = ...; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds += 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos += 1000000000; } Example 2: Compute Timestamp from Timestamp + Duration in pseudo code. Timestamp start = ...; Duration duration = ...; Timestamp end = ...; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos += 1000000000; } else if (end.nanos >= 1000000000) { end.seconds += 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix \"s\" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as \"3s\", while 3 seconds and 1 nanosecond should be expressed in JSON format as \"3.000000001s\", and 3 seconds and 1 microsecond should be expressed in JSON format as \"3.000001s\".- Returns:
- timeout
-
setTimeout
-
endpoint
-
getEndpoint
The new URL of the endpoint to call. If not set, the endpoint will not be changed.- Returns:
- endpoint
-
getEndpoint_JsonNullable
-
setEndpoint_JsonNullable
public void setEndpoint_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> endpoint) -
setEndpoint
-
expirationSigningKey
-
getExpirationSigningKey
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like \"day\" or \"month\". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +-10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = ...; Timestamp end = ...; Duration duration = ...; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds += 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos += 1000000000; } Example 2: Compute Timestamp from Timestamp + Duration in pseudo code. Timestamp start = ...; Duration duration = ...; Timestamp end = ...; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos += 1000000000; } else if (end.nanos >= 1000000000) { end.seconds += 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix \"s\" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as \"3s\", while 3 seconds and 1 nanosecond should be expressed in JSON format as \"3.000000001s\", and 3 seconds and 1 microsecond should be expressed in JSON format as \"3.000001s\".- Returns:
- expirationSigningKey
-
setExpirationSigningKey
-
payloadType
-
getPayloadType
Get payloadType- Returns:
- payloadType
-
setPayloadType
-
restAsync
-
getRestAsync
Get restAsync- Returns:
- restAsync
-
setRestAsync
-
restCall
-
getRestCall
Get restCall- Returns:
- restCall
-
setRestCall
-
restWebhook
-
getRestWebhook
Get restWebhook- Returns:
- restWebhook
-
setRestWebhook
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-