Package com.zitadel.model
Class ApplicationServiceUpdateOIDCApplicationConfigurationRequest
java.lang.Object
com.zitadel.model.ApplicationServiceUpdateOIDCApplicationConfigurationRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ApplicationServiceUpdateOIDCApplicationConfigurationRequest
extends Object
ApplicationServiceUpdateOIDCApplicationConfigurationRequest
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final String -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaccessTokenRoleAssertion(Boolean accessTokenRoleAssertion) accessTokenType(ApplicationServiceOIDCTokenType accessTokenType) addAdditionalOriginsItem(String additionalOriginsItem) addGrantTypesItem(ApplicationServiceOIDCGrantType grantTypesItem) additionalOrigins(List<String> additionalOrigins) addPostLogoutRedirectUrisItem(String postLogoutRedirectUrisItem) addRedirectUrisItem(String redirectUrisItem) addResponseTypesItem(ApplicationServiceOIDCResponseType responseTypesItem) applicationType(ApplicationServiceOIDCApplicationType applicationType) authMethodType(ApplicationServiceOIDCAuthMethodType authMethodType) backChannelLogoutUri(String backChannelLogoutUri) developmentMode(Boolean developmentMode) booleanIf AccessTokenRoleAssertion is enabled, the roles of the user are added to the access token.org.openapitools.jackson.nullable.JsonNullable<Boolean>Get accessTokenTypeAdditionalOrigins are HTTP origins (scheme + host + port) from where the API can be used additional to the redirect_uris.Get applicationTypeGet authMethodTypeBackChannelLogoutURI is used to notify the application about terminated sessions according to the OIDC Back-Channel Logout (https://openid.net/specs/openid-connect-backchannel-1_0.html).org.openapitools.jackson.nullable.JsonNullable<String>A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.DevelopmentMode can be enabled for development purposes.org.openapitools.jackson.nullable.JsonNullable<Boolean>GrantTypes define the flow type the application is allowed to use.If IDTokenRoleAssertion is enabled, the roles of the user are added to the id token.org.openapitools.jackson.nullable.JsonNullable<Boolean>If IDTokenUserinfoAssertion is enabled, the claims of profile, email, address and phone scopes are added to the id token even if an access token is issued.org.openapitools.jackson.nullable.JsonNullable<Boolean>Get loginVersionPostLogoutRedirectURIs are the allowed URIs to redirect to after a logout.RedirectURIs are the allowed callback URIs for the OAuth2 / OIDC flows, where the authorization code or tokens will be sent to.ResponseTypes define whether a code, id_token token or just id_token will be returned.For native apps a successful login usually shows a success page with a link to open the application again.org.openapitools.jackson.nullable.JsonNullable<Boolean>Get versiongrantTypes(List<ApplicationServiceOIDCGrantType> grantTypes) inthashCode()idTokenRoleAssertion(Boolean idTokenRoleAssertion) idTokenUserinfoAssertion(Boolean idTokenUserinfoAssertion) loginVersion(ApplicationServiceLoginVersion loginVersion) postLogoutRedirectUris(List<String> postLogoutRedirectUris) redirectUris(List<String> redirectUris) responseTypes(List<ApplicationServiceOIDCResponseType> responseTypes) voidsetAccessTokenRoleAssertion(Boolean accessTokenRoleAssertion) voidsetAccessTokenRoleAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> accessTokenRoleAssertion) voidsetAccessTokenType(ApplicationServiceOIDCTokenType accessTokenType) voidsetAdditionalOrigins(List<String> additionalOrigins) voidsetApplicationType(ApplicationServiceOIDCApplicationType applicationType) voidsetAuthMethodType(ApplicationServiceOIDCAuthMethodType authMethodType) voidsetBackChannelLogoutUri(String backChannelLogoutUri) voidsetBackChannelLogoutUri_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> backChannelLogoutUri) voidsetClockSkew(String clockSkew) voidsetDevelopmentMode(Boolean developmentMode) voidsetDevelopmentMode_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> developmentMode) voidsetGrantTypes(List<ApplicationServiceOIDCGrantType> grantTypes) voidsetIdTokenRoleAssertion(Boolean idTokenRoleAssertion) voidsetIdTokenRoleAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> idTokenRoleAssertion) voidsetIdTokenUserinfoAssertion(Boolean idTokenUserinfoAssertion) voidsetIdTokenUserinfoAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> idTokenUserinfoAssertion) voidsetLoginVersion(ApplicationServiceLoginVersion loginVersion) voidsetPostLogoutRedirectUris(List<String> postLogoutRedirectUris) voidsetRedirectUris(List<String> redirectUris) voidsetResponseTypes(List<ApplicationServiceOIDCResponseType> responseTypes) voidsetSkipNativeAppSuccessPage(Boolean skipNativeAppSuccessPage) voidsetSkipNativeAppSuccessPage_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> skipNativeAppSuccessPage) voidsetVersion(ApplicationServiceOIDCVersion version) skipNativeAppSuccessPage(Boolean skipNativeAppSuccessPage) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.version(ApplicationServiceOIDCVersion version)
-
Field Details
-
JSON_PROPERTY_REDIRECT_URIS
- See Also:
-
JSON_PROPERTY_RESPONSE_TYPES
- See Also:
-
JSON_PROPERTY_GRANT_TYPES
- See Also:
-
JSON_PROPERTY_APPLICATION_TYPE
- See Also:
-
JSON_PROPERTY_AUTH_METHOD_TYPE
- See Also:
-
JSON_PROPERTY_POST_LOGOUT_REDIRECT_URIS
- See Also:
-
JSON_PROPERTY_VERSION
- See Also:
-
JSON_PROPERTY_DEVELOPMENT_MODE
- See Also:
-
JSON_PROPERTY_ACCESS_TOKEN_TYPE
- See Also:
-
JSON_PROPERTY_ACCESS_TOKEN_ROLE_ASSERTION
- See Also:
-
JSON_PROPERTY_ID_TOKEN_ROLE_ASSERTION
- See Also:
-
JSON_PROPERTY_ID_TOKEN_USERINFO_ASSERTION
- See Also:
-
JSON_PROPERTY_CLOCK_SKEW
- See Also:
-
JSON_PROPERTY_ADDITIONAL_ORIGINS
- See Also:
-
JSON_PROPERTY_SKIP_NATIVE_APP_SUCCESS_PAGE
- See Also:
-
JSON_PROPERTY_BACK_CHANNEL_LOGOUT_URI
- See Also:
-
JSON_PROPERTY_LOGIN_VERSION
- See Also:
-
-
Constructor Details
-
ApplicationServiceUpdateOIDCApplicationConfigurationRequest
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest()
-
-
Method Details
-
redirectUris
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest redirectUris(@Nullable List<String> redirectUris) -
addRedirectUrisItem
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest addRedirectUrisItem(String redirectUrisItem) -
getRedirectUris
RedirectURIs are the allowed callback URIs for the OAuth2 / OIDC flows, where the authorization code or tokens will be sent to. The redirect_uri parameter in the authorization request must exactly match one of these URIs. Any existing redirect URIs not included in this list will be removed. If not set, the redirect URIs will not be changed.- Returns:
- redirectUris
-
setRedirectUris
-
responseTypes
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest responseTypes(@Nullable List<ApplicationServiceOIDCResponseType> responseTypes) -
addResponseTypesItem
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest addResponseTypesItem(ApplicationServiceOIDCResponseType responseTypesItem) -
getResponseTypes
ResponseTypes define whether a code, id_token token or just id_token will be returned. The response_type parameter in the authorization request must exactly match one of these values. Any existing response types not included in this list will be removed. If not set, the response types will not be changed.- Returns:
- responseTypes
-
setResponseTypes
-
grantTypes
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest grantTypes(@Nullable List<ApplicationServiceOIDCGrantType> grantTypes) -
addGrantTypesItem
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest addGrantTypesItem(ApplicationServiceOIDCGrantType grantTypesItem) -
getGrantTypes
GrantTypes define the flow type the application is allowed to use. The grant_type parameter in the token request must exactly match one of these values. Minimum one grant type must be provided, but multiple grant types can be provided to allow different flows, e.g. authorization code flow and refresh token flow. Any existing grant types not included in this list will be removed. If not set, the grant types will not be changed.- Returns:
- grantTypes
-
setGrantTypes
-
applicationType
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest applicationType(@Nullable ApplicationServiceOIDCApplicationType applicationType) -
getApplicationType
Get applicationType- Returns:
- applicationType
-
setApplicationType
-
authMethodType
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest authMethodType(@Nullable ApplicationServiceOIDCAuthMethodType authMethodType) -
getAuthMethodType
Get authMethodType- Returns:
- authMethodType
-
setAuthMethodType
-
postLogoutRedirectUris
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest postLogoutRedirectUris(@Nullable List<String> postLogoutRedirectUris) -
addPostLogoutRedirectUrisItem
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest addPostLogoutRedirectUrisItem(String postLogoutRedirectUrisItem) -
getPostLogoutRedirectUris
PostLogoutRedirectURIs are the allowed URIs to redirect to after a logout. The post_logout_redirect_uri parameter in the logout request must exactly match one of these URIs. Any existing post logout redirect URIs not included in this list will be removed. If not set, the post logout redirect URIs will not be changed.- Returns:
- postLogoutRedirectUris
-
setPostLogoutRedirectUris
-
version
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest version(@Nullable ApplicationServiceOIDCVersion version) -
getVersion
Get version- Returns:
- version
-
setVersion
-
developmentMode
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest developmentMode(@Nullable Boolean developmentMode) -
getDevelopmentMode
DevelopmentMode can be enabled for development purposes. This allows the use of OIDC non-compliant and potentially insecure settings, such as the use of HTTP redirect URIs or wildcard redirect URIs. If not set, the dev mode will not be changed.- Returns:
- developmentMode
-
getDevelopmentMode_JsonNullable
-
setDevelopmentMode_JsonNullable
public void setDevelopmentMode_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> developmentMode) -
setDevelopmentMode
-
accessTokenType
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest accessTokenType(@Nullable ApplicationServiceOIDCTokenType accessTokenType) -
getAccessTokenType
Get accessTokenType- Returns:
- accessTokenType
-
setAccessTokenType
-
accessTokenRoleAssertion
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest accessTokenRoleAssertion(@Nullable Boolean accessTokenRoleAssertion) -
getAccessTokenRoleAssertion
If AccessTokenRoleAssertion is enabled, the roles of the user are added to the access token. Ensure that the access token is a JWT token and not a bearer token. And either request the roles by scope or enable the user role assertion on the project. If not set, the access token role assertion will not be changed.- Returns:
- accessTokenRoleAssertion
-
getAccessTokenRoleAssertion_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<Boolean> getAccessTokenRoleAssertion_JsonNullable() -
setAccessTokenRoleAssertion_JsonNullable
public void setAccessTokenRoleAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> accessTokenRoleAssertion) -
setAccessTokenRoleAssertion
-
idTokenRoleAssertion
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest idTokenRoleAssertion(@Nullable Boolean idTokenRoleAssertion) -
getIdTokenRoleAssertion
If IDTokenRoleAssertion is enabled, the roles of the user are added to the id token. Ensure that either the roles are requested by scope or enable the user role assertion on the project. If not set, the id token role assertion will not be changed.- Returns:
- idTokenRoleAssertion
-
getIdTokenRoleAssertion_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<Boolean> getIdTokenRoleAssertion_JsonNullable() -
setIdTokenRoleAssertion_JsonNullable
public void setIdTokenRoleAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> idTokenRoleAssertion) -
setIdTokenRoleAssertion
-
idTokenUserinfoAssertion
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest idTokenUserinfoAssertion(@Nullable Boolean idTokenUserinfoAssertion) -
getIdTokenUserinfoAssertion
If IDTokenUserinfoAssertion is enabled, the claims of profile, email, address and phone scopes are added to the id token even if an access token is issued. This can be required by some applications that do not call the userinfo endpoint after authentication or directly use the id_token for retrieving user information. Attention: this violates the OIDC specification, which states that these claims must only be requested from the userinfo endpoint if an access token is issued. This is to prevent leaking of personal information in the id token, which is often stored in the browser and therefore more vulnerable. If not set, the id token userinfo assertion will not be changed.- Returns:
- idTokenUserinfoAssertion
-
getIdTokenUserinfoAssertion_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<Boolean> getIdTokenUserinfoAssertion_JsonNullable() -
setIdTokenUserinfoAssertion_JsonNullable
public void setIdTokenUserinfoAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> idTokenUserinfoAssertion) -
setIdTokenUserinfoAssertion
-
clockSkew
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest clockSkew(@Nullable String clockSkew) -
getClockSkew
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like \"day\" or \"month\". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +-10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = ...; Timestamp end = ...; Duration duration = ...; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds += 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos += 1000000000; } Example 2: Compute Timestamp from Timestamp + Duration in pseudo code. Timestamp start = ...; Duration duration = ...; Timestamp end = ...; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos += 1000000000; } else if (end.nanos >= 1000000000) { end.seconds += 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix \"s\" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as \"3s\", while 3 seconds and 1 nanosecond should be expressed in JSON format as \"3.000000001s\", and 3 seconds and 1 microsecond should be expressed in JSON format as \"3.000001s\".- Returns:
- clockSkew
-
setClockSkew
-
additionalOrigins
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest additionalOrigins(@Nullable List<String> additionalOrigins) -
addAdditionalOriginsItem
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest addAdditionalOriginsItem(String additionalOriginsItem) -
getAdditionalOrigins
AdditionalOrigins are HTTP origins (scheme + host + port) from where the API can be used additional to the redirect_uris. This is useful if the application is used from an origin different to the redirect_uris, e.g. if the application is a SPA served in a native app, where the redirect_uri is a custom scheme, but the application is served from a https origin. Any existing additional origins not included in this list will be removed. If not set, the additional origins will not be changed.- Returns:
- additionalOrigins
-
setAdditionalOrigins
-
skipNativeAppSuccessPage
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest skipNativeAppSuccessPage(@Nullable Boolean skipNativeAppSuccessPage) -
getSkipNativeAppSuccessPage
For native apps a successful login usually shows a success page with a link to open the application again. SkipNativeAppSuccessPage can be used to skip this page and open the application directly. If not set, the skip native app success page will not be changed.- Returns:
- skipNativeAppSuccessPage
-
getSkipNativeAppSuccessPage_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<Boolean> getSkipNativeAppSuccessPage_JsonNullable() -
setSkipNativeAppSuccessPage_JsonNullable
public void setSkipNativeAppSuccessPage_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> skipNativeAppSuccessPage) -
setSkipNativeAppSuccessPage
-
backChannelLogoutUri
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest backChannelLogoutUri(@Nullable String backChannelLogoutUri) -
getBackChannelLogoutUri
BackChannelLogoutURI is used to notify the application about terminated sessions according to the OIDC Back-Channel Logout (https://openid.net/specs/openid-connect-backchannel-1_0.html). If not set, the back channel logout URI will not be changed.- Returns:
- backChannelLogoutUri
-
getBackChannelLogoutUri_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<String> getBackChannelLogoutUri_JsonNullable() -
setBackChannelLogoutUri_JsonNullable
public void setBackChannelLogoutUri_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> backChannelLogoutUri) -
setBackChannelLogoutUri
-
loginVersion
public ApplicationServiceUpdateOIDCApplicationConfigurationRequest loginVersion(@Nullable ApplicationServiceLoginVersion loginVersion) -
getLoginVersion
Get loginVersion- Returns:
- loginVersion
-
setLoginVersion
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-