Package com.zitadel.model
Class BetaProjectServiceProject
java.lang.Object
com.zitadel.model.BetaProjectServiceProject
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class BetaProjectServiceProject
extends Object
BetaProjectServiceProject
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionauthorizationRequired(Boolean authorizationRequired) changeDate(OffsetDateTime changeDate) creationDate(OffsetDateTime creationDate) booleanWhen enabled ZITADEL will check if a user has an authorization to use this project assigned when login into an application of this project.A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.The ID of the organization the project is granted to.org.openapitools.jackson.nullable.JsonNullable<String>The name of the organization the project is granted to.org.openapitools.jackson.nullable.JsonNullable<String>Get grantedStategetId()The unique identifier of the project.getName()The name of the project.The unique identifier of the organization the project belongs to.Get privateLabelingSettingWhen enabled ZITADEL will check if the organization of the user, that is trying to log in, has access to this project (either owns the project or is granted).Describes if the roles of the user should be added to the token.getState()Get stategrantedOrganizationId(String grantedOrganizationId) grantedOrganizationName(String grantedOrganizationName) grantedState(BetaProjectServiceGrantedProjectState grantedState) inthashCode()organizationId(String organizationId) privateLabelingSetting(BetaProjectServicePrivateLabelingSetting privateLabelingSetting) projectAccessRequired(Boolean projectAccessRequired) projectRoleAssertion(Boolean projectRoleAssertion) voidsetAuthorizationRequired(Boolean authorizationRequired) voidsetChangeDate(OffsetDateTime changeDate) voidsetCreationDate(OffsetDateTime creationDate) voidsetGrantedOrganizationId(String grantedOrganizationId) voidsetGrantedOrganizationId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> grantedOrganizationId) voidsetGrantedOrganizationName(String grantedOrganizationName) voidsetGrantedOrganizationName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> grantedOrganizationName) voidsetGrantedState(BetaProjectServiceGrantedProjectState grantedState) voidvoidvoidsetOrganizationId(String organizationId) voidsetPrivateLabelingSetting(BetaProjectServicePrivateLabelingSetting privateLabelingSetting) voidsetProjectAccessRequired(Boolean projectAccessRequired) voidsetProjectRoleAssertion(Boolean projectRoleAssertion) voidtoString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_ID
- See Also:
-
JSON_PROPERTY_ORGANIZATION_ID
- See Also:
-
JSON_PROPERTY_CREATION_DATE
- See Also:
-
JSON_PROPERTY_CHANGE_DATE
- See Also:
-
JSON_PROPERTY_NAME
- See Also:
-
JSON_PROPERTY_STATE
- See Also:
-
JSON_PROPERTY_PROJECT_ROLE_ASSERTION
- See Also:
-
JSON_PROPERTY_AUTHORIZATION_REQUIRED
- See Also:
-
JSON_PROPERTY_PROJECT_ACCESS_REQUIRED
- See Also:
-
JSON_PROPERTY_PRIVATE_LABELING_SETTING
- See Also:
-
JSON_PROPERTY_GRANTED_ORGANIZATION_ID
- See Also:
-
JSON_PROPERTY_GRANTED_ORGANIZATION_NAME
- See Also:
-
JSON_PROPERTY_GRANTED_STATE
- See Also:
-
-
Constructor Details
-
BetaProjectServiceProject
public BetaProjectServiceProject()
-
-
Method Details
-
id
-
getId
The unique identifier of the project.- Returns:
- id
-
setId
-
organizationId
-
getOrganizationId
The unique identifier of the organization the project belongs to.- Returns:
- organizationId
-
setOrganizationId
-
creationDate
-
getCreationDate
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are \"smeared\" so that no leap second table is needed for interpretation, using a [24-hour linear smear](https://developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX `time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format. That is, the format is \"{year}-{month}-{day}T{hour}:{min}:{sec}[.{frac_sec}]Z\" where {year} is always expressed using four digits while {month}, {day}, {hour}, {min}, and {sec} are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The \"Z\" suffix indicates the timezone (\"UTC\"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by \"Z\") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, \"2017-01-15T01:30:15.01Z\" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](https://docs.python.org/2/library/time.html#time.strftime) with the time format spec '%Y-%m-%dT%H:%M:%S.%fZ'. Likewise, in Java, one can use the Joda Time's [`ISODateTimeFormat.dateTime()`]( http://joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.- Returns:
- creationDate
-
setCreationDate
-
changeDate
-
getChangeDate
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are \"smeared\" so that no leap second table is needed for interpretation, using a [24-hour linear smear](https://developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX `time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format. That is, the format is \"{year}-{month}-{day}T{hour}:{min}:{sec}[.{frac_sec}]Z\" where {year} is always expressed using four digits while {month}, {day}, {hour}, {min}, and {sec} are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The \"Z\" suffix indicates the timezone (\"UTC\"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by \"Z\") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, \"2017-01-15T01:30:15.01Z\" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](https://docs.python.org/2/library/time.html#time.strftime) with the time format spec '%Y-%m-%dT%H:%M:%S.%fZ'. Likewise, in Java, one can use the Joda Time's [`ISODateTimeFormat.dateTime()`]( http://joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.- Returns:
- changeDate
-
setChangeDate
-
name
-
getName
The name of the project.- Returns:
- name
-
setName
-
state
-
getState
Get state- Returns:
- state
-
setState
-
projectRoleAssertion
-
getProjectRoleAssertion
Describes if the roles of the user should be added to the token.- Returns:
- projectRoleAssertion
-
setProjectRoleAssertion
-
authorizationRequired
-
getAuthorizationRequired
When enabled ZITADEL will check if a user has an authorization to use this project assigned when login into an application of this project.- Returns:
- authorizationRequired
-
setAuthorizationRequired
-
projectAccessRequired
-
getProjectAccessRequired
When enabled ZITADEL will check if the organization of the user, that is trying to log in, has access to this project (either owns the project or is granted).- Returns:
- projectAccessRequired
-
setProjectAccessRequired
-
privateLabelingSetting
public BetaProjectServiceProject privateLabelingSetting(@Nullable BetaProjectServicePrivateLabelingSetting privateLabelingSetting) -
getPrivateLabelingSetting
Get privateLabelingSetting- Returns:
- privateLabelingSetting
-
setPrivateLabelingSetting
public void setPrivateLabelingSetting(@Nullable BetaProjectServicePrivateLabelingSetting privateLabelingSetting) -
grantedOrganizationId
-
getGrantedOrganizationId
The ID of the organization the project is granted to.- Returns:
- grantedOrganizationId
-
getGrantedOrganizationId_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<String> getGrantedOrganizationId_JsonNullable() -
setGrantedOrganizationId_JsonNullable
public void setGrantedOrganizationId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> grantedOrganizationId) -
setGrantedOrganizationId
-
grantedOrganizationName
-
getGrantedOrganizationName
The name of the organization the project is granted to.- Returns:
- grantedOrganizationName
-
getGrantedOrganizationName_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<String> getGrantedOrganizationName_JsonNullable() -
setGrantedOrganizationName_JsonNullable
public void setGrantedOrganizationName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> grantedOrganizationName) -
setGrantedOrganizationName
-
grantedState
public BetaProjectServiceProject grantedState(@Nullable BetaProjectServiceGrantedProjectState grantedState) -
getGrantedState
Get grantedState- Returns:
- grantedState
-
setGrantedState
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-