Package com.zitadel.model
Class BetaProjectServiceUpdateProjectRoleRequest
java.lang.Object
com.zitadel.model.BetaProjectServiceUpdateProjectRoleRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class BetaProjectServiceUpdateProjectRoleRequest
extends Object
BetaProjectServiceUpdateProjectRoleRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiondisplayName(String displayName) booleanName displayed for the role.org.openapitools.jackson.nullable.JsonNullable<String>getGroup()The group is only used for display purposes.org.openapitools.jackson.nullable.JsonNullable<String>ID of the project.The key is the only relevant attribute for ZITADEL regarding the authorization checks.inthashCode()voidsetDisplayName(String displayName) voidsetDisplayName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> displayName) voidvoidsetGroup_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> group) voidsetProjectId(String projectId) voidsetRoleKey(String roleKey) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
JSON_PROPERTY_ROLE_KEY
- See Also:
-
JSON_PROPERTY_DISPLAY_NAME
- See Also:
-
JSON_PROPERTY_GROUP
- See Also:
-
-
Constructor Details
-
BetaProjectServiceUpdateProjectRoleRequest
public BetaProjectServiceUpdateProjectRoleRequest()
-
-
Method Details
-
projectId
-
getProjectId
ID of the project.- Returns:
- projectId
-
setProjectId
-
roleKey
-
getRoleKey
The key is the only relevant attribute for ZITADEL regarding the authorization checks.- Returns:
- roleKey
-
setRoleKey
-
displayName
-
getDisplayName
Name displayed for the role.- Returns:
- displayName
-
getDisplayName_JsonNullable
-
setDisplayName_JsonNullable
public void setDisplayName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> displayName) -
setDisplayName
-
group
-
getGroup
The group is only used for display purposes. That you have better handling, like giving all the roles from a group to a user.- Returns:
- group
-
getGroup_JsonNullable
-
setGroup_JsonNullable
-
setGroup
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-