Package com.zitadel.model
Class BetaWebKeyServiceAny
- All Implemented Interfaces:
Serializable,Cloneable,Map<String,Object>
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class BetaWebKeyServiceAny
extends HashMap<String,Object>
Contains an arbitrary serialized message along with a @type that describes the type of the serialized message, with an additional debug field for ConnectRPC error details.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class java.util.AbstractMap
AbstractMap.SimpleEntry<K extends Object,V extends Object>, AbstractMap.SimpleImmutableEntry<K extends Object, V extends Object> -
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleangetDebug()Deserialized error detail payload.org.openapitools.jackson.nullable.JsonNullable<Object>getType()A URL that acts as a globally unique identifier for the type of the serialized message.getValue()The Protobuf message, serialized as bytes and base64-encoded.inthashCode()voidvoidsetDebug_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Object> debug) voidvoidtoString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.Methods inherited from class java.util.HashMap
clear, clone, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, forEach, get, getOrDefault, isEmpty, keySet, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, values
-
Field Details
-
JSON_PROPERTY_TYPE
- See Also:
-
JSON_PROPERTY_VALUE
- See Also:
-
JSON_PROPERTY_DEBUG
- See Also:
-
-
Constructor Details
-
BetaWebKeyServiceAny
public BetaWebKeyServiceAny()
-
-
Method Details
-
type
-
getType
A URL that acts as a globally unique identifier for the type of the serialized message. For example: `type.googleapis.com/google.rpc.ErrorInfo`. This is used to determine the schema of the data in the `value` field and is the discriminator for the `debug` field.- Returns:
- type
-
setType
-
value
-
getValue
The Protobuf message, serialized as bytes and base64-encoded. The specific message type is identified by the `type` field.- Returns:
- value
-
setValue
-
debug
-
getDebug
Deserialized error detail payload. The 'type' field indicates the schema. This field is for easier debugging and should not be relied upon for application logic.- Returns:
- debug
-
getDebug_JsonNullable
-
setDebug_JsonNullable
-
setDebug
-
equals
-
hashCode
public int hashCode() -
toString
- Overrides:
toStringin classAbstractMap<String,Object>
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-