Package com.zitadel.model
Class ProjectServiceProject
java.lang.Object
com.zitadel.model.ProjectServiceProject
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ProjectServiceProject
extends Object
ProjectServiceProject
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionauthorizationRequired(Boolean authorizationRequired) changeDate(OffsetDateTime changeDate) creationDate(OffsetDateTime creationDate) booleanAuthorizationRequired is a boolean flag that can be enabled to check if a user has an authorization to use this project assigned when login into an application of this project.A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.GrantedOrganizationID is the ID of the organization the project is granted to.org.openapitools.jackson.nullable.JsonNullable<String>GrantedOrganizationName is the name of the organization the project is granted to.org.openapitools.jackson.nullable.JsonNullable<String>Get grantedStategetName()Name is the name of the project.OrganizationID is the unique identifier of the organization the project belongs to.Get privateLabelingSettingProjectAccessRequired is a boolean flag that can be enabled to check if the organization of the user, that is trying to log in, has access to this project (either owns the project or is granted).ProjectID is the unique identifier of the project.ProjectRoleAssertion is a boolean flag that describes if the roles of the user should be added to the token.getState()Get stategrantedOrganizationId(String grantedOrganizationId) grantedOrganizationName(String grantedOrganizationName) grantedState(ProjectServiceGrantedProjectState grantedState) inthashCode()organizationId(String organizationId) privateLabelingSetting(ProjectServicePrivateLabelingSetting privateLabelingSetting) projectAccessRequired(Boolean projectAccessRequired) projectRoleAssertion(Boolean projectRoleAssertion) voidsetAuthorizationRequired(Boolean authorizationRequired) voidsetChangeDate(OffsetDateTime changeDate) voidsetCreationDate(OffsetDateTime creationDate) voidsetGrantedOrganizationId(String grantedOrganizationId) voidsetGrantedOrganizationId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> grantedOrganizationId) voidsetGrantedOrganizationName(String grantedOrganizationName) voidsetGrantedOrganizationName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> grantedOrganizationName) voidsetGrantedState(ProjectServiceGrantedProjectState grantedState) voidvoidsetOrganizationId(String organizationId) voidsetPrivateLabelingSetting(ProjectServicePrivateLabelingSetting privateLabelingSetting) voidsetProjectAccessRequired(Boolean projectAccessRequired) voidsetProjectId(String projectId) voidsetProjectRoleAssertion(Boolean projectRoleAssertion) voidstate(ProjectServiceProjectState state) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
JSON_PROPERTY_ORGANIZATION_ID
- See Also:
-
JSON_PROPERTY_CREATION_DATE
- See Also:
-
JSON_PROPERTY_CHANGE_DATE
- See Also:
-
JSON_PROPERTY_NAME
- See Also:
-
JSON_PROPERTY_STATE
- See Also:
-
JSON_PROPERTY_PROJECT_ROLE_ASSERTION
- See Also:
-
JSON_PROPERTY_AUTHORIZATION_REQUIRED
- See Also:
-
JSON_PROPERTY_PROJECT_ACCESS_REQUIRED
- See Also:
-
JSON_PROPERTY_PRIVATE_LABELING_SETTING
- See Also:
-
JSON_PROPERTY_GRANTED_ORGANIZATION_ID
- See Also:
-
JSON_PROPERTY_GRANTED_ORGANIZATION_NAME
- See Also:
-
JSON_PROPERTY_GRANTED_STATE
- See Also:
-
-
Constructor Details
-
ProjectServiceProject
public ProjectServiceProject()
-
-
Method Details
-
projectId
-
getProjectId
ProjectID is the unique identifier of the project.- Returns:
- projectId
-
setProjectId
-
organizationId
-
getOrganizationId
OrganizationID is the unique identifier of the organization the project belongs to.- Returns:
- organizationId
-
setOrganizationId
-
creationDate
-
getCreationDate
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are \"smeared\" so that no leap second table is needed for interpretation, using a [24-hour linear smear](https://developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX `time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format. That is, the format is \"{year}-{month}-{day}T{hour}:{min}:{sec}[.{frac_sec}]Z\" where {year} is always expressed using four digits while {month}, {day}, {hour}, {min}, and {sec} are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The \"Z\" suffix indicates the timezone (\"UTC\"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by \"Z\") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, \"2017-01-15T01:30:15.01Z\" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](https://docs.python.org/2/library/time.html#time.strftime) with the time format spec '%Y-%m-%dT%H:%M:%S.%fZ'. Likewise, in Java, one can use the Joda Time's [`ISODateTimeFormat.dateTime()`]( http://joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.- Returns:
- creationDate
-
setCreationDate
-
changeDate
-
getChangeDate
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are \"smeared\" so that no leap second table is needed for interpretation, using a [24-hour linear smear](https://developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX `time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format. That is, the format is \"{year}-{month}-{day}T{hour}:{min}:{sec}[.{frac_sec}]Z\" where {year} is always expressed using four digits while {month}, {day}, {hour}, {min}, and {sec} are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The \"Z\" suffix indicates the timezone (\"UTC\"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by \"Z\") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, \"2017-01-15T01:30:15.01Z\" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](https://docs.python.org/2/library/time.html#time.strftime) with the time format spec '%Y-%m-%dT%H:%M:%S.%fZ'. Likewise, in Java, one can use the Joda Time's [`ISODateTimeFormat.dateTime()`]( http://joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.- Returns:
- changeDate
-
setChangeDate
-
name
-
getName
Name is the name of the project. This might be presented to users, e.g. in sign-in flows.- Returns:
- name
-
setName
-
state
-
getState
Get state- Returns:
- state
-
setState
-
projectRoleAssertion
-
getProjectRoleAssertion
ProjectRoleAssertion is a boolean flag that describes if the roles of the user should be added to the token.- Returns:
- projectRoleAssertion
-
setProjectRoleAssertion
-
authorizationRequired
-
getAuthorizationRequired
AuthorizationRequired is a boolean flag that can be enabled to check if a user has an authorization to use this project assigned when login into an application of this project.- Returns:
- authorizationRequired
-
setAuthorizationRequired
-
projectAccessRequired
-
getProjectAccessRequired
ProjectAccessRequired is a boolean flag that can be enabled to check if the organization of the user, that is trying to log in, has access to this project (either owns the project or is granted).- Returns:
- projectAccessRequired
-
setProjectAccessRequired
-
privateLabelingSetting
public ProjectServiceProject privateLabelingSetting(@Nullable ProjectServicePrivateLabelingSetting privateLabelingSetting) -
getPrivateLabelingSetting
Get privateLabelingSetting- Returns:
- privateLabelingSetting
-
setPrivateLabelingSetting
public void setPrivateLabelingSetting(@Nullable ProjectServicePrivateLabelingSetting privateLabelingSetting) -
grantedOrganizationId
-
getGrantedOrganizationId
GrantedOrganizationID is the ID of the organization the project is granted to. In case the project is not granted, this field is unset.- Returns:
- grantedOrganizationId
-
getGrantedOrganizationId_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<String> getGrantedOrganizationId_JsonNullable() -
setGrantedOrganizationId_JsonNullable
public void setGrantedOrganizationId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> grantedOrganizationId) -
setGrantedOrganizationId
-
grantedOrganizationName
-
getGrantedOrganizationName
GrantedOrganizationName is the name of the organization the project is granted to. In case the project is not granted, this field is unset.- Returns:
- grantedOrganizationName
-
getGrantedOrganizationName_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<String> getGrantedOrganizationName_JsonNullable() -
setGrantedOrganizationName_JsonNullable
public void setGrantedOrganizationName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> grantedOrganizationName) -
setGrantedOrganizationName
-
grantedState
-
getGrantedState
Get grantedState- Returns:
- grantedState
-
setGrantedState
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-