Package com.zitadel.model
Class ProjectServiceRemoveProjectRoleRequest
java.lang.Object
com.zitadel.model.ProjectServiceRemoveProjectRoleRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ProjectServiceRemoveProjectRoleRequest
extends Object
ProjectServiceRemoveProjectRoleRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanProjectID is the unique identifier of the project.RoleKey is the key of the role to be removed.inthashCode()voidsetProjectId(String projectId) voidsetRoleKey(String roleKey) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
JSON_PROPERTY_ROLE_KEY
- See Also:
-
-
Constructor Details
-
ProjectServiceRemoveProjectRoleRequest
public ProjectServiceRemoveProjectRoleRequest()
-
-
Method Details
-
projectId
-
getProjectId
ProjectID is the unique identifier of the project.- Returns:
- projectId
-
setProjectId
-
roleKey
-
getRoleKey
RoleKey is the key of the role to be removed. All dependencies of this role will be removed as well, including project grants and user grants. If the role is not found, the request will return a successful response as the desired state is already achieved.- Returns:
- roleKey
-
setRoleKey
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-