Package com.zitadel.model
Class ProjectServiceUpdateProjectGrantRequest
java.lang.Object
com.zitadel.model.ProjectServiceUpdateProjectGrantRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ProjectServiceUpdateProjectGrantRequest
extends Object
ProjectServiceUpdateProjectGrantRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddRoleKeysItem(String roleKeysItem) booleanGrantedOrganizationID is the unique identifier of the organization the project was granted to.ProjectID is the unique identifier of the project.RoleKeys is a list of roles to be granted to the organization for self management.grantedOrganizationId(String grantedOrganizationId) inthashCode()voidsetGrantedOrganizationId(String grantedOrganizationId) voidsetProjectId(String projectId) voidsetRoleKeys(List<String> roleKeys) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
JSON_PROPERTY_GRANTED_ORGANIZATION_ID
- See Also:
-
JSON_PROPERTY_ROLE_KEYS
- See Also:
-
-
Constructor Details
-
ProjectServiceUpdateProjectGrantRequest
public ProjectServiceUpdateProjectGrantRequest()
-
-
Method Details
-
projectId
-
getProjectId
ProjectID is the unique identifier of the project.- Returns:
- projectId
-
setProjectId
-
grantedOrganizationId
public ProjectServiceUpdateProjectGrantRequest grantedOrganizationId(@Nullable String grantedOrganizationId) -
getGrantedOrganizationId
GrantedOrganizationID is the unique identifier of the organization the project was granted to.- Returns:
- grantedOrganizationId
-
setGrantedOrganizationId
-
roleKeys
-
addRoleKeysItem
-
getRoleKeys
RoleKeys is a list of roles to be granted to the organization for self management. The roles are identified by their keys. Any roles not included in this list will be removed from the project grant. If you want to add a role, make sure to include all other existing roles as well. If any previous role is removed, all user grants for this project grant with this role will be removed as well.- Returns:
- roleKeys
-
setRoleKeys
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-