Package com.zitadel.model
Class ProjectServiceUpdateProjectRequest
java.lang.Object
com.zitadel.model.ProjectServiceUpdateProjectRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ProjectServiceUpdateProjectRequest
extends Object
ProjectServiceUpdateProjectRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionauthorizationRequired(Boolean authorizationRequired) booleanAuthorizationRequired is a boolean flag that can be enabled to check if a user has a role of this project assigned when logging into an application of this project.org.openapitools.jackson.nullable.JsonNullable<Boolean>getName()Name is used to update the name of the project.org.openapitools.jackson.nullable.JsonNullable<String>Get privateLabelingSettingProjectAccessRequired is a boolean flag that can be enabled to check if the organization of the user has a grant to this project.org.openapitools.jackson.nullable.JsonNullable<Boolean>ProjectID is the unique identifier of the project to be updated.ProjectRoleAssertion is a setting that can be enabled to have role information included in the user info endpoint.org.openapitools.jackson.nullable.JsonNullable<Boolean>inthashCode()privateLabelingSetting(ProjectServicePrivateLabelingSetting privateLabelingSetting) projectAccessRequired(Boolean projectAccessRequired) projectRoleAssertion(Boolean projectRoleAssertion) voidsetAuthorizationRequired(Boolean authorizationRequired) voidsetAuthorizationRequired_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> authorizationRequired) voidvoidsetName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> name) voidsetPrivateLabelingSetting(ProjectServicePrivateLabelingSetting privateLabelingSetting) voidsetProjectAccessRequired(Boolean projectAccessRequired) voidsetProjectAccessRequired_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> projectAccessRequired) voidsetProjectId(String projectId) voidsetProjectRoleAssertion(Boolean projectRoleAssertion) voidsetProjectRoleAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> projectRoleAssertion) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
JSON_PROPERTY_NAME
- See Also:
-
JSON_PROPERTY_PROJECT_ROLE_ASSERTION
- See Also:
-
JSON_PROPERTY_AUTHORIZATION_REQUIRED
- See Also:
-
JSON_PROPERTY_PROJECT_ACCESS_REQUIRED
- See Also:
-
JSON_PROPERTY_PRIVATE_LABELING_SETTING
- See Also:
-
-
Constructor Details
-
ProjectServiceUpdateProjectRequest
public ProjectServiceUpdateProjectRequest()
-
-
Method Details
-
projectId
-
getProjectId
ProjectID is the unique identifier of the project to be updated.- Returns:
- projectId
-
setProjectId
-
name
-
getName
Name is used to update the name of the project. This field is optional. If omitted, the name will remain unchanged.- Returns:
- name
-
getName_JsonNullable
-
setName_JsonNullable
-
setName
-
projectRoleAssertion
public ProjectServiceUpdateProjectRequest projectRoleAssertion(@Nullable Boolean projectRoleAssertion) -
getProjectRoleAssertion
ProjectRoleAssertion is a setting that can be enabled to have role information included in the user info endpoint. It is also dependent on your application settings to include it in tokens and other types. If omitted, the setting will remain unchanged.- Returns:
- projectRoleAssertion
-
getProjectRoleAssertion_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<Boolean> getProjectRoleAssertion_JsonNullable() -
setProjectRoleAssertion_JsonNullable
public void setProjectRoleAssertion_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> projectRoleAssertion) -
setProjectRoleAssertion
-
authorizationRequired
public ProjectServiceUpdateProjectRequest authorizationRequired(@Nullable Boolean authorizationRequired) -
getAuthorizationRequired
AuthorizationRequired is a boolean flag that can be enabled to check if a user has a role of this project assigned when logging into an application of this project. If omitted, the setting will remain unchanged.- Returns:
- authorizationRequired
-
getAuthorizationRequired_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<Boolean> getAuthorizationRequired_JsonNullable() -
setAuthorizationRequired_JsonNullable
public void setAuthorizationRequired_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> authorizationRequired) -
setAuthorizationRequired
-
projectAccessRequired
public ProjectServiceUpdateProjectRequest projectAccessRequired(@Nullable Boolean projectAccessRequired) -
getProjectAccessRequired
ProjectAccessRequired is a boolean flag that can be enabled to check if the organization of the user has a grant to this project. If omitted, the setting will remain unchanged.- Returns:
- projectAccessRequired
-
getProjectAccessRequired_JsonNullable
public org.openapitools.jackson.nullable.JsonNullable<Boolean> getProjectAccessRequired_JsonNullable() -
setProjectAccessRequired_JsonNullable
public void setProjectAccessRequired_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<Boolean> projectAccessRequired) -
setProjectAccessRequired
-
privateLabelingSetting
public ProjectServiceUpdateProjectRequest privateLabelingSetting(@Nullable ProjectServicePrivateLabelingSetting privateLabelingSetting) -
getPrivateLabelingSetting
Get privateLabelingSetting- Returns:
- privateLabelingSetting
-
setPrivateLabelingSetting
public void setPrivateLabelingSetting(@Nullable ProjectServicePrivateLabelingSetting privateLabelingSetting) -
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-