Package com.zitadel.model
Class ProjectServiceUpdateProjectRoleRequest
java.lang.Object
com.zitadel.model.ProjectServiceUpdateProjectRoleRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class ProjectServiceUpdateProjectRoleRequest
extends Object
ProjectServiceUpdateProjectRoleRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiondisplayName(String displayName) booleanDisplayName is the human readable name for the role, which might be displayed to users.org.openapitools.jackson.nullable.JsonNullable<String>getGroup()Group allows grouping roles for display purposes.org.openapitools.jackson.nullable.JsonNullable<String>ProjectID is the unique identifier of the project.RoleKey identifies the role.inthashCode()voidsetDisplayName(String displayName) voidsetDisplayName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> displayName) voidvoidsetGroup_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> group) voidsetProjectId(String projectId) voidsetRoleKey(String roleKey) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_PROJECT_ID
- See Also:
-
JSON_PROPERTY_ROLE_KEY
- See Also:
-
JSON_PROPERTY_DISPLAY_NAME
- See Also:
-
JSON_PROPERTY_GROUP
- See Also:
-
-
Constructor Details
-
ProjectServiceUpdateProjectRoleRequest
public ProjectServiceUpdateProjectRoleRequest()
-
-
Method Details
-
projectId
-
getProjectId
ProjectID is the unique identifier of the project.- Returns:
- projectId
-
setProjectId
-
roleKey
-
getRoleKey
RoleKey identifies the role. It's the only relevant attribute for ZITADEL and will be used for authorization checks and as claim in tokens and user info responses. It cannot be changed. If you need a different key, remove the role and create a new one.- Returns:
- roleKey
-
setRoleKey
-
displayName
-
getDisplayName
DisplayName is the human readable name for the role, which might be displayed to users. If omitted, the name will remain unchanged.- Returns:
- displayName
-
getDisplayName_JsonNullable
-
setDisplayName_JsonNullable
public void setDisplayName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> displayName) -
setDisplayName
-
group
-
getGroup
Group allows grouping roles for display purposes. Zitadel will not handle it in any way. It can be used to group roles in a UI to allow easier management for administrators. If omitted, the group will remain unchanged. This attribute is not to be confused with groups as a collection of users.- Returns:
- group
-
getGroup_JsonNullable
-
setGroup_JsonNullable
-
setGroup
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-