Package com.zitadel.model
Class SessionServiceCheckRecoveryCode
java.lang.Object
com.zitadel.model.SessionServiceCheckRecoveryCode
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class SessionServiceCheckRecoveryCode
extends Object
SessionServiceCheckRecoveryCode
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleangetCode()The Recovery Code of the user to be checked.inthashCode()voidtoString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_CODE
- See Also:
-
-
Constructor Details
-
SessionServiceCheckRecoveryCode
public SessionServiceCheckRecoveryCode()
-
-
Method Details
-
code
-
getCode
The Recovery Code of the user to be checked. The code must match the exact code previously generated for the user, including dashes if any. On successful check, the recovery code will be invalidated and cannot be used again.- Returns:
- code
-
setCode
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-