Package com.zitadel.model
Class SessionServiceSetSessionRequest
java.lang.Object
com.zitadel.model.SessionServiceSetSessionRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class SessionServiceSetSessionRequest
extends Object
SessionServiceSetSessionRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionchallenges(SessionServiceRequestChallenges challenges) checks(SessionServiceChecks checks) booleanGet challengesGet checksA Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.Additional custom key value pairs to be stored on the session.The unique identifier of the session to be updated.Deprecated.inthashCode()putMetadataItem(String key, byte[] metadataItem) sessionToken(String sessionToken) voidsetChallenges(SessionServiceRequestChallenges challenges) voidsetChecks(SessionServiceChecks checks) voidsetLifetime(String lifetime) voidsetMetadata(Map<String, byte[]> metadata) voidsetSessionId(String sessionId) voidsetSessionToken(String sessionToken) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_SESSION_ID
- See Also:
-
JSON_PROPERTY_SESSION_TOKEN
- See Also:
-
JSON_PROPERTY_CHECKS
- See Also:
-
JSON_PROPERTY_METADATA
- See Also:
-
JSON_PROPERTY_CHALLENGES
- See Also:
-
JSON_PROPERTY_LIFETIME
- See Also:
-
-
Constructor Details
-
SessionServiceSetSessionRequest
public SessionServiceSetSessionRequest()
-
-
Method Details
-
sessionId
-
getSessionId
The unique identifier of the session to be updated.- Returns:
- sessionId
-
setSessionId
-
sessionToken
-
getSessionToken
Deprecated.Deprecated: the session token is no longer required when updating a session and will be ignored when provided.- Returns:
- sessionToken
-
setSessionToken
-
checks
-
getChecks
Get checks- Returns:
- checks
-
setChecks
-
metadata
-
putMetadataItem
-
getMetadata
Additional custom key value pairs to be stored on the session. Existing keys will be overwritten. To delete a key, set its value to an empty byte array. Note that metadata keys cannot be changed once the session has been created. You need to create a new entry and delete the old one instead.- Returns:
- metadata
-
setMetadata
-
challenges
public SessionServiceSetSessionRequest challenges(@Nullable SessionServiceRequestChallenges challenges) -
getChallenges
Get challenges- Returns:
- challenges
-
setChallenges
-
lifetime
-
getLifetime
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like \"day\" or \"month\". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +-10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = ...; Timestamp end = ...; Duration duration = ...; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds += 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos += 1000000000; } Example 2: Compute Timestamp from Timestamp + Duration in pseudo code. Timestamp start = ...; Duration duration = ...; Timestamp end = ...; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos += 1000000000; } else if (end.nanos >= 1000000000) { end.seconds += 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix \"s\" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as \"3s\", while 3 seconds and 1 nanosecond should be expressed in JSON format as \"3.000000001s\", and 3 seconds and 1 microsecond should be expressed in JSON format as \"3.000001s\".- Returns:
- lifetime
-
setLifetime
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-