Package com.zitadel.model
Class UserServiceCreateUserRequest
java.lang.Object
com.zitadel.model.UserServiceCreateUserRequest
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class UserServiceCreateUserRequest
extends Object
UserServiceCreateUserRequest
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleangetHuman()Get humanGet machineThe unique identifier of the organization the user belongs to.The ID is a unique identifier for the user in the instance.org.openapitools.jackson.nullable.JsonNullable<String>The username is a unique identifier for the user in the organization.org.openapitools.jackson.nullable.JsonNullable<String>inthashCode()human(UserServiceHuman human) machine(UserServiceMachine machine) organizationId(String organizationId) voidsetHuman(UserServiceHuman human) voidsetMachine(UserServiceMachine machine) voidsetOrganizationId(String organizationId) voidvoidsetUserId_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> userId) voidsetUsername(String username) voidsetUsername_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> username) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.
-
Field Details
-
JSON_PROPERTY_ORGANIZATION_ID
- See Also:
-
JSON_PROPERTY_USER_ID
- See Also:
-
JSON_PROPERTY_USERNAME
- See Also:
-
JSON_PROPERTY_HUMAN
- See Also:
-
JSON_PROPERTY_MACHINE
- See Also:
-
-
Constructor Details
-
UserServiceCreateUserRequest
public UserServiceCreateUserRequest()
-
-
Method Details
-
organizationId
-
getOrganizationId
The unique identifier of the organization the user belongs to.- Returns:
- organizationId
-
setOrganizationId
-
userId
-
getUserId
The ID is a unique identifier for the user in the instance. If not specified, it will be generated. You can set your own user id that is unique within the instance. This is useful in migration scenarios, for example if the user already has an ID in another Zitadel system. If not specified, it will be generated. It can't be changed after creation.- Returns:
- userId
-
getUserId_JsonNullable
-
setUserId_JsonNullable
-
setUserId
-
username
-
getUsername
The username is a unique identifier for the user in the organization. If not specified, Zitadel sets the username to the email for users of type human and to the user_id for users of type machine. It is used to identify the user in the organization and can be used for login.- Returns:
- username
-
getUsername_JsonNullable
-
setUsername_JsonNullable
public void setUsername_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> username) -
setUsername
-
human
-
getHuman
Get human- Returns:
- human
-
setHuman
-
machine
-
getMachine
Get machine- Returns:
- machine
-
setMachine
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-