Package com.zitadel.model
Class UserServiceSendInviteCode
java.lang.Object
com.zitadel.model.UserServiceSendInviteCode
@Generated(value="io.github.mridang.codegen.generators.java.BetterJavaCodegen",
comments="Generator version: 7.14.0")
public class UserServiceSendInviteCode
extends Object
UserServiceSendInviteCode
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionapplicationName(String applicationName) booleanOptionally set an application name, which will be used in the invite mail sent by ZITADEL.org.openapitools.jackson.nullable.JsonNullable<String>Optionally set a url_template, which will be used in the invite mail sent by ZITADEL to guide the user to your invitation page.org.openapitools.jackson.nullable.JsonNullable<String>inthashCode()voidsetApplicationName(String applicationName) voidsetApplicationName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> applicationName) voidsetUrlTemplate(String urlTemplate) voidsetUrlTemplate_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> urlTemplate) toString()Convert the instance into URL query string.toUrlQueryString(String prefix) Convert the instance into URL query string.urlTemplate(String urlTemplate)
-
Field Details
-
JSON_PROPERTY_URL_TEMPLATE
- See Also:
-
JSON_PROPERTY_APPLICATION_NAME
- See Also:
-
-
Constructor Details
-
UserServiceSendInviteCode
public UserServiceSendInviteCode()
-
-
Method Details
-
urlTemplate
-
getUrlTemplate
Optionally set a url_template, which will be used in the invite mail sent by ZITADEL to guide the user to your invitation page. If no template is set and no previous code was created, the default ZITADEL url will be used. The following placeholders can be used: UserID, OrgID, Code- Returns:
- urlTemplate
-
getUrlTemplate_JsonNullable
-
setUrlTemplate_JsonNullable
public void setUrlTemplate_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> urlTemplate) -
setUrlTemplate
-
applicationName
-
getApplicationName
Optionally set an application name, which will be used in the invite mail sent by ZITADEL. If no application name is set and no previous code was created, ZITADEL will be used as default.- Returns:
- applicationName
-
getApplicationName_JsonNullable
-
setApplicationName_JsonNullable
public void setApplicationName_JsonNullable(org.openapitools.jackson.nullable.JsonNullable<String> applicationName) -
setApplicationName
-
equals
-
hashCode
public int hashCode() -
toString
-
toUrlQueryString
Convert the instance into URL query string.- Returns:
- URL query string
-
toUrlQueryString
Convert the instance into URL query string.- Parameters:
prefix- prefix of the query string- Returns:
- URL query string
-