Package com.zitadel.utils
Class StringUtil
java.lang.Object
com.zitadel.utils.StringUtil
-
Method Summary
-
Method Details
-
join
Join an array of strings with the given separator.Note: This might be replaced by utility method from commons-lang or guava someday if one of those libraries is added as dependency.
- Parameters:
array- The array of stringsseparator- The separator- Returns:
- the resulting string
-